@@ -7,9 +7,37 @@ from .FinError import FinError
 from numba import njit, boolean, int64
 import numpy as np
 
+
+###############################################################################    
+
+from enum import Enum
+
+class FinDateFormatTypes(Enum):
+    BLOOMBERG = 1
+    US_SHORT = 2
+    US_MEDIUM = 3
+    US_LONG = 4
+    US_LONGEST = 5
+    UK_SHORT = 6
+    UK_MEDIUM = 7
+    UK_LONG = 8
+    UK_LONGEST = 9
+    DATETIME = 10
+    
+
+# Set the default
+gDateFormatType = FinDateFormatTypes.UK_LONG
+
+def setDateFormatType(formatType):
+    ''' Function that sets the global date format type. '''
+    global gDateFormatType
+    gDateFormatType = formatType
+
+###############################################################################    
+
 ENFORCE_DAY_FIRST = True
 
-##########################################################################
+###############################################################################
 
 shortDayNames = ['MON', 'TUE', 'WED', 'THU', 'FRI', 'SAT', 'SUN']
 longDayNames = [
@@ -59,10 +87,13 @@ def isLeapYear(y: int):
     leapYear = ((y % 4 == 0) and (y % 100 != 0) or (y % 400 == 0))
     return leapYear
 
+###############################################################################
+
 
 def parse_date(dateStr, dateFormat):
     dt_obj = datetime.datetime.strptime(dateStr, dateFormat)
     return dt_obj.day, dt_obj.month, dt_obj.year
+
 ###############################################################################
 # CREATE DATE COUNTER
 ###############################################################################
@@ -120,19 +151,19 @@ def calculateList():
                 if yy >= gStartYear:
                     gDateCounterList.append(-999)
 
-
-##############################################################################
+###############################################################################
 # The index in these functions is not the excel date index used as the 
 # internal representation of the date but the index of that date in the
 # padded date object used to store the dates in a way that allows for a
 # quick lookup. Do not confuse them as you will find they are out by months
-##############################################################################
+###############################################################################
 
 @njit(fastmath=True, cache=True)
 def dateIndex(d, m, y):
     idx = (y-gStartYear) * 12 * 31 + (m-1) * 31 + (d-1)
     return idx
 
+###############################################################################
 
 @njit(fastmath=True, cache=True)
 def dateFromIndex(idx):
@@ -157,6 +188,7 @@ class FinDate():
     ''' A date class to manage dates that is simple to use and includes a
     number of useful date functions used frequently in Finance. '''
 
+
     MON = 0
     TUE = 1
     WED = 2
@@ -167,24 +199,19 @@ class FinDate():
 
     ###########################################################################
 
-    def __init__(self, *args):  # Year number which must be between 1900 and 2100
+    def __init__(self, d, m, y, hh=0, mm=0, ss=0):  
         ''' Create a date given a day of month, month and year. The arguments
         must be in the order of day (of month), month number and then the year.
-        The year must be a 4-digit number greater than or equal to 1900.
+        The year must be a 4-digit number greater than or equal to 1900. The
+        user can also supply an hour, minute and second for intraday work.
 
         Example Input:
-        start_date = FinDate('1-1-2018', '%d-%m-%Y')
         start_date = FinDate(1, 1, 2018)
         '''
 
         global gStartYear
         global gEndYear
 
-        if isinstance(args[0], str):
-           d, m, y = parse_date(args[0], args[1])
-        else:
-           d, m, y = args[0], args[1], args[2]
-
         # If the date has been entered as y, m, d we flip it to d, m, y
         if d >= gStartYear and d < gEndYear and y > 0 and y <= 31:
             tmp = y
@@ -225,14 +252,45 @@ class FinDate():
                 print(d, m, y)
                 raise FinError("Date: Not Leap year. Day not valid.")
 
+        if hh < 0 or hh > 23:
+            raise FinError("Hours must be in range 0-23")
+
+        if mm < 0 or mm > 59:
+            raise FinError("Minutes must be in range 0-59")
+
+        if ss < 0 or ss > 59:
+            raise FinError("Seconds must be in range 0-59")
+
         self._y = y
         self._m = m
         self._d = d
-        self._excelDate = 0
+        
+        self._hh = hh
+        self._mm = mm
+        self._ss = ss
+
+        self._excelDate = 0 # This is a float as it includes intraday time
 
         # update the excel date used for doing lots of financial calculations
         self._refresh()
 
+        dayFraction = self._hh/24.0
+        dayFraction += self._mm/24.0/60.0
+        dayFraction += self._ss/24.0/60.0/60.0
+
+        self._excelDate += dayFraction # This is a float as it includes intraday time
+
+    ###########################################################################
+
+    @classmethod
+    def fromString(cls, dateString, formatString):
+        '''  Create a FinDate from a date and format string.
+        Example Input:
+        start_date = FinDate('1-1-2018', '%d-%m-%Y') '''
+ 
+        d, m, y = parse_date(dateString, formatString)
+        return cls(d, m, y)
+
     ###########################################################################
 
     def _refresh(self):
@@ -287,6 +345,26 @@ class FinDate():
 
     ###########################################################################
 
+    def addHours(self, hours):
+        ''' Returns a new date that is h hours after the FinDate. '''
+
+        if hours < 0:
+            raise FinError("Number of hours must be positive")
+        
+        startHour = self._hh        
+        finalHour = startHour + hours
+        days = int(finalHour/24)
+        hour = finalHour % 24
+
+        # Move forward a specific number of days
+        dt1 = self.addDays(days)
+
+        # On that date we then move to the correct hour
+        dt2 = FinDate(dt1._d, dt1._m, dt1._y, hour, dt1._mm, dt1._ss)                
+        return dt2
+
+    ###########################################################################
+
     def addDays(self,
                 numDays: int = 1):
         ''' Returns a new date that is numDays after the FinDate. I also make
@@ -610,21 +688,129 @@ class FinDate():
         ''' Returns a datetime of the date '''
         return datetime.date(self._d, self._m, self._y)
 
+    ###########################################################################
+    # TODO: Find elegant way to return long and short strings
+    ###########################################################################
+
+    def str(self, format):
+        ''' returns a formatted string of the date '''
+        dateStr = ""
+
+        if self._d < 10:
+            dateStr += "0" + str(self._d) + ""
+        else:
+            dateStr += "" + str(self._d) + ""
+
+        dateStr += shortMonthNames[self._m - 1]
+        dateStr += "" + str(self._y)
+        return dateStr
+
     ###########################################################################
 
     def __repr__(self):
         ''' returns a formatted string of the date '''
-        dateStr = ""
-        dateStr += shortDayNames[self._weekday]
+
+        global gDateFormatType
+        
+        dayNameStr = shortDayNames[self._weekday]
 
         if self._d < 10:
-            dateStr += " 0" + str(self._d) + " "
+            dayStr = "0" + str(self._d)
         else:
-            dateStr += " " + str(self._d) + " "
+            dayStr = "" + str(self._d)
 
-        dateStr += shortMonthNames[self._m - 1]
-        dateStr += " " + str(self._y)
-        return dateStr
+        if self._m < 10:
+            shortMonthStr = "0" + str(self._m)
+        else:
+            shortMonthStr = str(self._m)
+
+        longMonthStr = shortMonthNames[self._m - 1]
+
+        shortYearStr = str(self._y)[2:]
+        longYearStr = str(self._y)
+
+        
+        if gDateFormatType == FinDateFormatTypes.UK_LONGEST:
+
+            sep = " "
+            dateStr = dayNameStr + " " + dayStr + sep + longMonthStr + sep + longYearStr
+            return dateStr
+
+        elif gDateFormatType == FinDateFormatTypes.UK_LONG:
+
+            sep = "-"
+            dateStr = dayStr + sep + longMonthStr + sep + longYearStr
+            return dateStr
+
+        elif gDateFormatType == FinDateFormatTypes.UK_MEDIUM:
+
+            sep = "/"
+            dateStr = dayStr + sep + shortMonthStr + sep + longYearStr
+            return dateStr
+    
+        elif gDateFormatType == FinDateFormatTypes.UK_SHORT:
+
+            sep = "/"
+            dateStr = dayStr + sep + shortMonthStr + sep + shortYearStr
+            return dateStr
+
+        elif gDateFormatType == FinDateFormatTypes.US_LONGEST:
+
+            sep = " "
+            dateStr = dayNameStr + " " + longMonthStr + sep + dayStr + sep + longYearStr
+            return dateStr
+
+        elif gDateFormatType == FinDateFormatTypes.US_LONG:
+
+            sep = "-"
+            dateStr = longMonthStr + sep + dayStr + sep + longYearStr
+            return dateStr
+
+        elif gDateFormatType == FinDateFormatTypes.US_MEDIUM:
+            
+            sep = "-"
+            dateStr = shortMonthStr + sep + dayStr + sep + longYearStr
+            return dateStr
+
+        elif gDateFormatType == FinDateFormatTypes.US_SHORT:
+
+            sep = "-"
+            dateStr = shortMonthStr + sep + dayStr + sep + shortYearStr
+            return dateStr
+
+        elif gDateFormatType == FinDateFormatTypes.BLOOMBERG:
+
+            sep = "/"
+            dateStr = shortMonthStr + sep + dayStr + sep + shortYearStr
+            return dateStr
+
+        elif gDateFormatType == FinDateFormatTypes.DATETIME:
+
+            sep = "/"
+
+            if self._hh < 10:
+                hourStr = "0" + str(self._hh)
+            else:
+                hourStr = str(self._hh)
+
+            if self._mm < 10:
+                minuteStr = "0" + str(self._mm)
+            else:
+                minuteStr = str(self._mm)
+
+            if self._ss < 10:
+                secondStr = "0" + str(self._ss)
+            else:
+                secondStr = str(self._ss)
+
+            timeStr = hourStr + ":" + minuteStr + ":" + secondStr
+            dateStr = dayStr + sep + shortMonthStr + sep + longYearStr
+            dateStr = dateStr + " " + timeStr
+            return dateStr
+
+        else:
+            
+            raise FinError("Unknown date format")
 
     ###########################################################################
     # REMOVE THIS
@@ -633,8 +819,6 @@ class FinDate():
         ''' prints formatted string of the date. '''
         print(self)
 
-    ###########################################################################
-
 
 ###############################################################################
 # Date functions that are not class members but are useful
@@ -664,7 +848,7 @@ def datediff(d1: FinDate,
              d2: FinDate):
     ''' Calculate the number of days between two Findates. '''
     dd = (d2._excelDate - d1._excelDate)
-    return dd
+    return int(dd)
 
 ###############################################################################
 
@@ -712,3 +896,9 @@ def dateRange(startDate: FinDate,
     return dateList
 
 ###############################################################################
+
+def testType():
+    global gDateFormatType
+    print("TEST TYPE", gDateFormatType)
+    
+###############################################################################
