@@ -76,7 +76,7 @@ class FinDayCount(object):
                  dt1: FinDate,    # Start of coupon period
                  dt2: FinDate,    # Settlement (for bonds) or period end(swaps)
                  dt3: FinDate = None,   # End of coupon period for accrued
-                 frequencyType: FinFrequencyTypes = FinFrequencyTypes.ANNUAL,
+                 freqType: FinFrequencyTypes = FinFrequencyTypes.ANNUAL,
                  isTerminationDate: bool = False):  # Is dt2 a termination date
         ''' This method performs two functions:
 
@@ -89,6 +89,11 @@ class FinDayCount(object):
         must be set to the next coupon date. You will also need to provide a
         coupon frequency for some conventions.
 
+        Note that if the date is intraday, i.e. hh,mm and ss do not equal zero
+        then that is used in the calculation of the year frac. This avoids 
+        discontinuities for short dated intra day products. It should not
+        affect normal dates for which hh=mm=ss=0.
+        
         This seems like a useful source:
         https://www.eclipsesoftware.biz/DayCountConventions.html
         Wikipedia also has a decent survey of the conventions
@@ -210,7 +215,7 @@ class FinDayCount(object):
 
         elif self._type == FinDayCountTypes.ACT_ACT_ICMA:
 
-            freq = FinFrequency(frequencyType)
+            freq = FinFrequency(freqType)
 
             if dt3 is None or freq is None:
                 raise FinError("ACT_ACT_ICMA requires three dates and a freq")
@@ -239,7 +244,7 @@ class FinDayCount(object):
             # The ISDA calculator sheet appears to split this across the
             # non-leap and the leap year which I do not see in any conventions.
 
-            freq = FinFrequency(frequencyType)
+            freq = FinFrequency(freqType)
 
             if dt3 is None:
                 y3 = y2
