@@ -29,8 +29,8 @@ class FinCapFloorTypes(Enum):
 ###############################################################################
 
 class FinSwapTypes(Enum):
-    PAYER = 1
-    RECEIVER = 2
+    PAY = 1
+    RECEIVE = 2
 
 ###############################################################################
 
