@@ -1,10 +1,15 @@
 from .FinCalendar import *
+from .FinCurrency import *
 from .FinDate import *
 from .FinDayCount import *
 from .FinFrequency import *
 from .FinGlobalVariables import *
+from .FinGlobalTypes import *
 from .FinHelperFunctions import *
 from .FinMath import *
 from .FinStatistics import *
 from .FinSchedule import *
+from .FinError import *
+from .FinCurrency import *
+from .FinAmount import *
 
