@@ -3,7 +3,7 @@
 ##############################################################################
 
 import numpy as np
-from numba import jit, njit, float64, int64
+from numba import njit, float64, int64
 from ..finutils.FinMath import cholesky
 
 ###############################################################################
