@@ -9,7 +9,7 @@ import numpy as np
 from ..finutils.FinMath import N
 from ..finutils.FinGlobalVariables import gSmall
 from ..finutils.FinHelperFunctions import labelToString
-from ..finutils.FinOptionTypes import FinOptionTypes
+from ..finutils.FinGlobalTypes import FinOptionTypes
 from ..finutils.FinError import FinError
 
 ###############################################################################
