@@ -7,12 +7,12 @@ from numba import njit, float64, int64
 
 from ..finutils.FinError import FinError
 from ..finutils.FinMath import accruedInterpolator
-from ..market.curves.FinInterpolate import FinInterpTypes, _uinterpolate
+from ..market.curves.FinInterpolator import FinInterpTypes, _uinterpolate
 from ..finutils.FinHelperFunctions import labelToString
 from ..finutils.FinGlobalTypes import FinExerciseTypes
 from ..finutils.FinGlobalVariables import gSmall
 
-interp = FinInterpTypes.FLAT_FORWARDS.value
+interp = FinInterpTypes.FLAT_FWD_RATES.value
 
 ###############################################################################
 # TODO: PUT CALL PARITY IS NOT EXACTLY OBSERVED FOR BERMUDAN SWAPTIONS WHEN 
@@ -677,7 +677,7 @@ class FinModelRatesBDT():
         if isinstance(dfValues, np.ndarray) is False:
             raise FinError("DF VALUES must be a numpy vector")
 
-        interp = FinInterpTypes.FLAT_FORWARDS.value
+        interp = FinInterpTypes.FLAT_FWD_RATES.value
 
         treeMaturity = treeMat * (self._numTimeSteps+1)/self._numTimeSteps
         treeTimes = np.linspace(0.0, treeMaturity, self._numTimeSteps + 2)
@@ -691,7 +691,7 @@ class FinModelRatesBDT():
             dfTree[i] = _uinterpolate(t, dfTimes, dfValues, interp)
 
         self._dfTimes = dfTimes
-        self._dfValues = dfValues
+        self._dfs = dfValues
 
         self._Q, self._rt, self._dt \
             = buildTreeFast(self._sigma,
@@ -723,7 +723,7 @@ class FinModelRatesBDT():
                                            strikePrice, faceAmount,
                                            couponTimes, couponFlows,
                                            exerciseTypeInt,
-                                           self._dfTimes, self._dfValues,
+                                           self._dfTimes, self._dfs,
                                            self._treeTimes, self._Q,
                                            self._rt,
                                            self._dt)
@@ -755,7 +755,7 @@ class FinModelRatesBDT():
                                          strike, faceAmount,
                                          couponTimes, couponFlows,
                                          exerciseTypeInt,
-                                         self._dfTimes, self._dfValues,
+                                         self._dfTimes, self._dfs,
                                          self._treeTimes, self._Q,
                                          self._rt,
                                          self._dt)
@@ -786,7 +786,7 @@ class FinModelRatesBDT():
                                            self._Q,
                                            self._rt, self._dt,
                                            self._treeTimes,
-                                           self._dfTimes, self._dfValues)
+                                           self._dfTimes, self._dfs)
 
         return {'bondwithoption': v['bondwithoption'],
                 'bondpure': v['bondpure']}
