@@ -9,7 +9,7 @@ from numba import njit
 # TODO: Add perturbatory risk using the analytical methods !!
 # TODO: Add Sobol to Monte Carlo
 
-from ...finutils.FinMath import N, covar
+from ...finutils.FinMath import covar
 from ...finutils.FinGlobalVariables import gDaysInYear
 from ...finutils.FinError import FinError
 
@@ -18,6 +18,9 @@ from ...finutils.FinHelperFunctions import checkArgumentTypes, labelToString
 from ...finutils.FinDate import FinDate
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
 
+from ...finutils.FinMath import N
+
+
 ###############################################################################
 
 from enum import Enum
@@ -120,6 +123,7 @@ def _valueMC_NUMBA(t0,
 
             s_1 = s_1 * np.exp((mu - v2 / 2.0) * dt +
                                g[obs] * np.sqrt(dt) * volatility)
+
             s_2 = s_2 * np.exp((mu - v2 / 2.0) * dt -
                                g[obs] * np.sqrt(dt) * volatility)
 
