@@ -14,8 +14,8 @@ from ...finutils.FinHelperFunctions import labelToString, checkArgumentTypes
 from ...finutils.FinDate import FinDate
 
 
-from scipy.stats import norm
-N = norm.cdf
+from ...finutils.FinMath import N
+
 
 ###############################################################################
 
