@@ -8,21 +8,20 @@ import numpy as np
 from ...finutils.FinFrequency import FinFrequencyTypes
 from ...finutils.FinGlobalVariables import gDaysInYear
 from ...finutils.FinError import FinError
+from ...finutils.FinGlobalTypes import FinOptionTypes
 
-from ...products.equity.FinEquityOption import FinEquityOption
-from ...market.curves.FinDiscountCurveFlat import FinDiscountCurve
 from ...finutils.FinHelperFunctions import labelToString, checkArgumentTypes
 from ...finutils.FinDate import FinDate
-from ...finutils.FinDayCount import FinDayCount, FinDayCountTypes
-from ...models.FinModelBlackScholes import bsValue
+from ...finutils.FinDayCount import FinDayCountTypes
 from ...finutils.FinCalendar import FinBusDayAdjustTypes
 from ...finutils.FinCalendar import FinCalendarTypes,  FinDateGenRuleTypes
 from ...finutils.FinSchedule import FinSchedule
-from ...products.equity.FinEquityModelTypes import FinEquityModelBlackScholes
-from ...finutils.FinGlobalTypes import FinOptionTypes
+from ...products.equity.FinEquityOption import FinEquityOption
+from ...market.curves.FinDiscountCurveFlat import FinDiscountCurve
+
+from ...models.FinModelBlackScholes import bsValue, FinModelBlackScholes
+from ...models.FinModel import FinModel
 
-from scipy.stats import norm
-N = norm.cdf
 
 ###############################################################################
 # TODO: Do we need to day count adjust option payoffs ?
@@ -42,7 +41,7 @@ class FinEquityCliquetOption(FinEquityOption):
                  startDate: FinDate,
                  finalExpiryDate: FinDate,
                  optionType: FinOptionTypes,
-                 frequencyType: FinFrequencyTypes,
+                 freqType: FinFrequencyTypes,
                  dayCountType: FinDayCountTypes = FinDayCountTypes.THIRTY_E_360,
                  calendarType: FinCalendarTypes = FinCalendarTypes.WEEKEND,
                  busDayAdjustType: FinBusDayAdjustTypes = FinBusDayAdjustTypes.FOLLOWING,
@@ -63,7 +62,7 @@ class FinEquityCliquetOption(FinEquityOption):
         self._startDate = startDate
         self._finalExpiryDate = finalExpiryDate
         self._optionType = optionType
-        self._frequencyType = frequencyType
+        self._freqType = freqType
         self._dayCountType = dayCountType
         self._calendarType = calendarType
         self._busDayAdjustType = busDayAdjustType
@@ -71,7 +70,7 @@ class FinEquityCliquetOption(FinEquityOption):
 
         self._expiryDates = FinSchedule(self._startDate,
                                         self._finalExpiryDate,
-                                        self._frequencyType,
+                                        self._freqType,
                                         self._calendarType,
                                         self._busDayAdjustType,
                                         self._dateGenRuleType)._generate()
@@ -83,7 +82,7 @@ class FinEquityCliquetOption(FinEquityOption):
               stockPrice: float,
               discountCurve: FinDiscountCurve,
               dividendYield: float,
-              model):
+              model:FinModel):
         ''' Value the cliquet option as a sequence of options using the Black-
         Scholes model. '''
 
@@ -98,7 +97,7 @@ class FinEquityCliquetOption(FinEquityOption):
         self._dfs = []
         self._actualDates = []
 
-        if type(model) == FinEquityModelBlackScholes:
+        if isinstance(model, FinModelBlackScholes):
 
             vol = model._volatility
             vol = max(vol, 1e-6)
@@ -146,7 +145,7 @@ class FinEquityCliquetOption(FinEquityOption):
         s += labelToString("START DATE", self._startDate)
         s += labelToString("FINAL EXPIRY DATE", self._finalExpiryDate)
         s += labelToString("OPTION TYPE", self._optionType)
-        s += labelToString("FREQUENCY TYPE", self._frequencyType)
+        s += labelToString("FREQUENCY TYPE", self._freqType)
         s += labelToString("DAY COUNT TYPE", self._dayCountType)
         s += labelToString("CALENDAR TYPE", self._calendarType)
         s += labelToString("BUS DAY ADJUST TYPE", self._busDayAdjustType)
