@@ -4,13 +4,14 @@
 
 import numpy as np
 from scipy import optimize
+import copy
 
 from ...finutils.FinError import FinError
 from ...finutils.FinDate import FinDate
 from ...finutils.FinHelperFunctions import labelToString
 from ...finutils.FinHelperFunctions import checkArgumentTypes, _funcName
 from ...finutils.FinGlobalVariables import gDaysInYear
-from ...market.curves.FinInterpolate import FinInterpTypes
+from ...market.curves.FinInterpolator import FinInterpTypes, FinInterpolator
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
 from ...products.funding.FinIborDeposit import FinIborDeposit
 from ...products.funding.FinIborFRA import FinIborFRA
@@ -18,9 +19,9 @@ from ...products.funding.FinIborSwap import FinIborSwap
 
 swaptol = 1e-10
 
-##############################################################################
+###############################################################################
 # TODO: CHANGE times to dfTimes
-##############################################################################
+###############################################################################
 
 
 def _f(df, *args):
@@ -29,12 +30,16 @@ def _f(df, *args):
     indexCurve = args[1]
     valueDate = args[2]
     swap = args[3]
-    numPoints = len(indexCurve._times)
-    indexCurve._dfValues[numPoints - 1] = df
-    v_swap = swap.value(valueDate, discountCurve, indexCurve, None, 1.0)
-    v_swap /= swap._notional
-#    print("FINIBORDUALCURVE calling _f", numPoints, df, v_swap)
 
+    numPoints = len(indexCurve._times)
+    indexCurve._dfs[numPoints - 1] = df
+
+    # For curves that need a fit function, we fit it now 
+    indexCurve._interpolator.fit(indexCurve._times, indexCurve._dfs)     
+    v_swap = swap.value(valueDate, discountCurve, indexCurve, None)
+
+    notional = swap._fixedLeg._notional
+    v_swap /= notional
     return v_swap
 
 ###############################################################################
@@ -42,13 +47,17 @@ def _f(df, *args):
 
 def _g(df, *args):
     ''' Root search objective function for swaps '''
+
     discountCurve = args[0]
-    indexCurve = args[1]
+    curve = args[1]
     valueDate = args[2]
     fra = args[3]
-    numPoints = len(indexCurve._times)
-    indexCurve._dfValues[numPoints - 1] = df
-    v_fra = fra.value(valueDate, discountCurve, indexCurve)
+    numPoints = len(curve._times)
+    curve._dfs[numPoints - 1] = df
+
+    # For curves that need a fit function, we fit it now 
+    curve._interpolator.fit(curve._times, curve._dfs)     
+    v_fra = fra.value(valueDate, discountCurve, curve)
     v_fra /= fra._notional
     return v_fra
 
@@ -68,7 +77,7 @@ class FinIborDualCurve(FinDiscountCurve):
                  iborDeposits: list,
                  iborFRAs: list,
                  iborSwaps: list,
-                 interpType: FinInterpTypes = FinInterpTypes.FLAT_FORWARDS,
+                 interpType: FinInterpTypes = FinInterpTypes.FLAT_FWD_RATES,
                  checkRefit: bool = False):  # Set to True to test it works
         ''' Create an instance of a FinIbor curve given a valuation date and
         a set of ibor deposits, ibor FRAs and iborSwaps. Some of these may
@@ -93,11 +102,8 @@ class FinIborDualCurve(FinDiscountCurve):
 
     def _buildCurve(self):
         ''' Build curve based on interpolation. '''
-#        if self._interpType == FinInterpTypes.LINEAR_SWAP_RATES:
-#            self._buildCurveLinearSwapRateInterpolation()
-#        else:
-            
-        self._buildCurveUsingSolver()
+
+        self._buildCurveUsing1DSolver()
 
 ###############################################################################
 
@@ -111,19 +117,30 @@ class FinIborDualCurve(FinDiscountCurve):
         numFRAs = len(iborFRAs)
         numSwaps = len(iborSwaps)
 
+        depoStartDate = self._valuationDate
+        swapStartDate = self._valuationDate
+
         if numDepos + numFRAs + numSwaps == 0:
             raise FinError("No calibration instruments.")
 
         # Validation of the inputs.
         if numDepos > 0:
+
+            depoStartDate = iborDeposits[0]._startDate
+
             for depo in iborDeposits:
+
                 if isinstance(depo, FinIborDeposit) is False:
                     raise FinError("Deposit is not of type FinIborDeposit")
 
                 startDt = depo._startDate
+
                 if startDt < self._valuationDate:
                     raise FinError("First deposit starts before value date.")
 
+                if startDt < depoStartDate:
+                    depoStartDate = startDt
+
             for depo in iborDeposits:
                 startDt = depo._startDate
                 endDt = depo._maturityDate
@@ -132,18 +149,20 @@ class FinIborDualCurve(FinDiscountCurve):
 
         # Ensure order of depos
         if numDepos > 1:
-            prevDt = iborDeposits[0]._maturityDate
 
+            prevDt = iborDeposits[0]._maturityDate
             for depo in iborDeposits[1:]:
                 nextDt = depo._maturityDate
                 if nextDt <= prevDt:
                     raise FinError("Deposits must be in increasing maturity")
                 prevDt = nextDt
 
+        # REMOVED THIS AS WE WANT TO ANCHOR CURVE AT VALUATION DATE 
+        # USE A SYNTHETIC DEPOSIT TO BRIDGE GAP FROM VALUE DATE TO SETTLEMENT DATE
         # Ensure that valuation date is on or after first deposit start date
-        if numDepos > 1:
-            if iborDeposits[0]._startDate > self._valuationDate:
-                raise FinError("Valuation date must not be before first deposit settles.")
+        # if numDepos > 1:
+        #    if iborDeposits[0]._effectiveDate > self._valuationDate:
+        #        raise FinError("Valuation date must not be before first deposit settles.")
 
         if numFRAs > 0:
             for fra in iborFRAs:
@@ -163,19 +182,27 @@ class FinIborDualCurve(FinDiscountCurve):
                 prevDt = nextDt
 
         if numSwaps > 0:
+
+            swapStartDate = iborSwaps[0]._effectiveDate
+
             for swap in iborSwaps:
+
                 if isinstance(swap, FinIborSwap) is False:
                     raise FinError("Swap is not of type FinIborSwap")
-                startDt = swap._startDate
+
+                startDt = swap._effectiveDate
                 if startDt < self._valuationDate:
                     raise FinError("Swaps starts before valuation date.")
 
+                if swap._effectiveDate < swapStartDate:
+                    swapStartDate = swap._effectiveDate
+
         if numSwaps > 1:
 
             # Swaps must all start on the same date for the bootstrap
-            startDt = iborSwaps[0]._startDate
+            startDt = iborSwaps[0]._effectiveDate
             for swap in iborSwaps[1:]:
-                nextStartDt = swap._startDate
+                nextStartDt = swap._effectiveDate
                 if nextStartDt != startDt:
                     raise FinError("Swaps must all have same start date.")
 
@@ -189,9 +216,9 @@ class FinIborDualCurve(FinDiscountCurve):
 
             # Swaps must have same cashflows for bootstrap to work
             longestSwap = iborSwaps[-1]
-            longestSwapCpnDates = longestSwap._adjustedFixedDates
+            longestSwapCpnDates = longestSwap._fixedLeg._paymentDates
             for swap in iborSwaps[0:-1]:
-                swapCpnDates = swap._adjustedFixedDates
+                swapCpnDates = swap._fixedLeg._paymentDates
                 numFlows = len(swapCpnDates)
                 for iFlow in range(0, numFlows):
                     if swapCpnDates[iFlow] != longestSwapCpnDates[iFlow]:
@@ -225,6 +252,24 @@ class FinIborDualCurve(FinDiscountCurve):
             if firstSwapMaturityDate <= lastFRAMaturityDate:
                 raise FinError("First Swap must mature after last FRA")
 
+        # If both depos and swaps start after T, we need a rate to get them to
+        # the first deposit. So we create a synthetic deposit rate contract.
+        
+        if swapStartDate > self._valuationDate:
+
+            if numDepos == 0:
+                raise FinError("Need a deposit rate to pin down short end.")
+
+            if depoStartDate > self._valuationDate:
+                firstDepo = iborDeposits[0]
+                if firstDepo._startDate > self._valuationDate:
+                    print("Inserting synthetic deposit")
+                    syntheticDeposit = copy.deepcopy(firstDepo)
+                    syntheticDeposit._startDate = self._valuationDate
+                    syntheticDeposit._maturityDate = firstDepo._startDate
+                    iborDeposits.insert(0, syntheticDeposit)
+                    numDepos += 1
+
         # Now determine which instruments are used
         self._usedDeposits = iborDeposits
         self._usedFRAs = iborFRAs
@@ -233,20 +278,23 @@ class FinIborDualCurve(FinDiscountCurve):
 
 ###############################################################################
 
-    def _buildCurveUsingSolver(self):
+    def _buildCurveUsing1DSolver(self):
         ''' Construct the discount curve using a bootstrap approach. This is
         the non-linear slower method that allows the user to choose a number
         of interpolation approaches between the swap rates and other rates. It
         involves the use of a solver. '''
 
+        self._interpolator = FinInterpolator(self._interpType)
+
         self._times = np.array([])
-        self._dfValues = np.array([])
+        self._dfs = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfValues = np.append(self._dfValues, dfMat)
+        self._dfs = np.append(self._dfs, dfMat)
+        self._interpolator.fit(self._times, self._dfs)
 
         # A deposit is not margined and not indexed to Libor so should
         # probably not be used to build an indexed Libor curve from
@@ -255,7 +303,8 @@ class FinIborDualCurve(FinDiscountCurve):
             dfMat = depo._maturityDf() * dfSettle
             tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
+            self._interpolator.fit(self._times, self._dfs)
 
         oldtmat = tmat
 
@@ -270,11 +319,10 @@ class FinIborDualCurve(FinDiscountCurve):
             if tset < oldtmat and tmat > oldtmat:
                 dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
-
+                self._dfs = np.append(self._dfs, dfMat)
                 argtuple = (self._discountCurve, self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
                                         args=argtuple, tol=swaptol,
@@ -283,11 +331,11 @@ class FinIborDualCurve(FinDiscountCurve):
         for swap in self._usedSwaps:
             # I use the lastPaymentDate in case a date has been adjusted fwd
             # over a holiday as the maturity date is usually not adjusted CHECK
-            maturityDate = swap._lastPaymentDate
+            maturityDate = swap._fixedLeg._paymentDates[-1]
             tmat = (maturityDate - self._valuationDate) / gDaysInYear
 
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
 
             argtuple = (self._discountCurve, self, self._valuationDate, swap)
 
@@ -300,137 +348,146 @@ class FinIborDualCurve(FinDiscountCurve):
 
 ###############################################################################
 
-    def _buildCurveLinearSwapRateInterpolation(self):
-        ''' Construct the discount curve using a bootstrap approach. This is
-        the linear swap rate method that is fast and exact as it does not
-        require the use of a solver. It is also market standard. '''
+    # def _buildCurveLinearSwapRateInterpolation(self):
+    #     ''' Construct the discount curve using a bootstrap approach. This is
+    #     the linear swap rate method that is fast and exact as it does not
+    #     require the use of a solver. It is also market standard. '''
 
-        self._times = np.array([])
-        self._dfValues = np.array([])
+    #     self._interpolator = FinInterpolator(self._interpType)
 
-        # time zero is now.
-        tmat = 0.0
-        dfMat = 1.0
-        self._times = np.append(self._times, 0.0)
-        self._dfValues = np.append(self._dfValues, dfMat)
+    #     self._times = np.array([])
+    #     self._dfs = np.array([])
 
-        for depo in self._usedDeposits:
-            dfSettle = self.df(depo._startDate)
-            dfMat = depo._maturityDf() * dfSettle
-            tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
-            self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+    #     # time zero is now.
+    #     tmat = 0.0
+    #     dfMat = 1.0
+    #     self._times = np.append(self._times, 0.0)
+    #     self._dfs = np.append(self._dfs, dfMat)
+    #     self._interpolator.fit(self._times, self._dfs)
 
-        oldtmat = tmat
+    #     for depo in self._usedDeposits:
+    #         dfSettle = self.df(depo._effectiveDate)
+    #         dfMat = depo._maturityDf() * dfSettle
+    #         tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
+    #         self._times = np.append(self._times, tmat)
+    #         self._dfs = np.append(self._dfs, dfMat)
+    #         self._interpolator.fit(self._times, self._dfs)
 
-        for fra in self._usedFRAs:
+    #     oldtmat = tmat
 
-            tset = (fra._startDate - self._valuationDate) / gDaysInYear
-            tmat = (fra._maturityDate - self._valuationDate) / gDaysInYear
+    #     for fra in self._usedFRAs:
 
-            # if both dates are after the previous FRA/FUT then need to
-            # solve for 2 discount factors simultaneously using root search
+    #         tset = (fra._startDate - self._valuationDate) / gDaysInYear
+    #         tmat = (fra._maturityDate - self._valuationDate) / gDaysInYear
 
-            if tset < oldtmat and tmat > oldtmat:
-                dfMat = fra.maturityDf(self)
-                self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
-            else:
-                self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+    #         # if both dates are after the previous FRA/FUT then need to
+    #         # solve for 2 discount factors simultaneously using root search
 
-                argtuple = (self, self._valuationDate, fra)
-                dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
-                                        args=argtuple, tol=swaptol,
-                                        maxiter=50, fprime2=None)
+    #         if tset < oldtmat and tmat > oldtmat:
+    #             dfMat = fra.maturityDf(self)
+    #             self._times = np.append(self._times, tmat)
+    #             self._dfs = np.append(self._dfs, dfMat)
+    #             self._interpolator.fit(self._times, self._dfs)
+    #         else:
+    #             self._times = np.append(self._times, tmat)
+    #             self._dfs = np.append(self._dfs, dfMat)
+    #             self._interpolator.fit(self._times, self._dfs)
 
-        if len(self._usedSwaps) == 0:
-            if self._checkRefit is True:
-                self._checkRefits(1e-10, swaptol, 1e-5)
-            return
+    #             argtuple = (self._discountCurve, self, self._valuationDate, fra)
+    #             dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
+    #                                     args=argtuple, tol=swaptol,
+    #                                     maxiter=50, fprime2=None)
 
-        #######################################################################
-        # ADD SWAPS TO CURVE
-        #######################################################################
+    #     if len(self._usedSwaps) == 0:
+    #         if self._checkRefit is True:
+    #             self._checkRefits(1e-10, swaptol, 1e-5)
+    #         return
 
-        # Find where the FRAs and Depos go up to as this bit of curve is done
-        foundStart = False
-        lastDate = self._valuationDate
-        if len(self._usedDeposits) != 0:
-            lastDate = self._usedDeposits[-1]._maturityDate
+    #     #######################################################################
+    #     # ADD SWAPS TO CURVE
+    #     #######################################################################
 
-        if len(self._usedFRAs) != 0:
-            lastDate = self._usedFRAs[-1]._maturityDate
+    #     # Find where the FRAs and Depos go up to as this bit of curve is done
+    #     foundStart = False
+    #     lastDate = self._valuationDate
+    #     if len(self._usedDeposits) != 0:
+    #         lastDate = self._usedDeposits[-1]._maturityDate
 
-        # We use the longest swap assuming it has a superset of ALL of the
-        # swap flow dates used in the curve construction
-        longestSwap = self._usedSwaps[-1]
-        couponDates = longestSwap._adjustedFixedDates
-        numFlows = len(couponDates)
+    #     if len(self._usedFRAs) != 0:
+    #         lastDate = self._usedFRAs[-1]._maturityDate
 
-        # Find where first coupon without discount factor starts
-        startIndex = 0
-        for i in range(0, numFlows):
-            if couponDates[i] > lastDate:
-                startIndex = i
-                foundStart = True
-                break
+    #     # We use the longest swap assuming it has a superset of ALL of the
+    #     # swap flow dates used in the curve construction
+    #     longestSwap = self._usedSwaps[-1]
+    #     couponDates = longestSwap._adjustedFixedDates
+    #     numFlows = len(couponDates)
 
-        if foundStart is False:
-            raise FinError("Found start is false. Swaps payments inside FRAs")
+    #     # Find where first coupon without discount factor starts
+    #     startIndex = 0
+    #     for i in range(0, numFlows):
+    #         if couponDates[i] > lastDate:
+    #             startIndex = i
+    #             foundStart = True
+    #             break
 
-        swapRates = []
-        swapTimes = []
+    #     if foundStart is False:
+    #         raise FinError("Found start is false. Swaps payments inside FRAs")
 
-        # I use the last coupon date for the swap rate interpolation as this
-        # may be different from the maturity date due to a holiday adjustment
-        # and the swap rates need to align with the coupon payment dates
-        for swap in self._usedSwaps:
-            swapRate = swap._fixedCoupon
-            maturityDate = swap._adjustedFixedDates[-1]
-            tswap = (maturityDate - self._valuationDate) / gDaysInYear
-            swapTimes.append(tswap)
-            swapRates.append(swapRate)
+    #     swapRates = []
+    #     swapTimes = []
 
-        interpolatedSwapRates = [0.0]
-        interpolatedSwapTimes = [0.0]
+    #     # I use the last coupon date for the swap rate interpolation as this
+    #     # may be different from the maturity date due to a holiday adjustment
+    #     # and the swap rates need to align with the coupon payment dates
+    #     for swap in self._usedSwaps:
+    #         swapRate = swap._fixedCoupon
+    #         maturityDate = swap._adjustedFixedDates[-1]
+    #         tswap = (maturityDate - self._valuationDate) / gDaysInYear
+    #         swapTimes.append(tswap)
+    #         swapRates.append(swapRate)
 
-        for dt in couponDates[1:]:
-            swapTime = (dt - self._valuationDate) / gDaysInYear
-            swapRate = np.interp(swapTime, swapTimes, swapRates)
-            interpolatedSwapRates.append(swapRate)
-            interpolatedSwapTimes.append(swapTime)
+    #     interpolatedSwapRates = [0.0]
+    #     interpolatedSwapTimes = [0.0]
 
-        # Do I need this line ?
-        interpolatedSwapRates[0] = interpolatedSwapRates[1]
+    #     for dt in couponDates[1:]:
+    #         swapTime = (dt - self._valuationDate) / gDaysInYear
+    #         swapRate = np.interp(swapTime, swapTimes, swapRates)
+    #         interpolatedSwapRates.append(swapRate)
+    #         interpolatedSwapTimes.append(swapTime)
 
-        accrualFactors = longestSwap._fixedYearFracs
+    #     # Do I need this line ?
+    #     interpolatedSwapRates[0] = interpolatedSwapRates[1]
 
-        acc = 0.0
-        df = 1.0
-        pv01 = 0.0
-        dfSettle = self.df(longestSwap._startDate)
+    #     accrualFactors = longestSwap._fixedYearFracs
 
-        for i in range(1, startIndex):
-            dt = couponDates[i]
-            df = self.df(dt)
-            acc = accrualFactors[i-1]
-            pv01 += acc * df
+    #     acc = 0.0
+    #     df = 1.0
+    #     pv01 = 0.0
+    #     dfSettle = self.df(longestSwap._effectiveDate)
 
-        for i in range(startIndex, numFlows):
+    #     for i in range(1, startIndex):
+    #         dt = couponDates[i]
+    #         df = self.df(dt)
+    #         acc = accrualFactors[i-1]
+    #         pv01 += acc * df
 
-            dt = couponDates[i]
-            tmat = (dt - self._valuationDate) / gDaysInYear
-            swapRate = interpolatedSwapRates[i]
-            acc = accrualFactors[i-1]
-            pv01End = (acc * swapRate + 1.0)
-            dfMat = (dfSettle - swapRate * pv01) / pv01End
-            self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
-            pv01 += acc * dfMat
+    #     for i in range(startIndex, numFlows):
 
-        if self._checkRefit is True:
-            self._checkRefits(1e-10, swaptol, 1e-5)
+    #         dt = couponDates[i]
+    #         tmat = (dt - self._valuationDate) / gDaysInYear
+    #         swapRate = interpolatedSwapRates[i]
+    #         acc = accrualFactors[i-1]
+    #         pv01End = (acc * swapRate + 1.0)
+    #         dfMat = (dfSettle - swapRate * pv01) / pv01End
+
+    #         self._times = np.append(self._times, tmat)
+    #         self._dfs = np.append(self._dfs, dfMat)
+    #         self._interpolator.fit(self._times, self._dfs)
+
+    #         pv01 += acc * dfMat
+
+    #     if self._checkRefit is True:
+    #         self._checkRefits(1e-10, swaptol, 1e-5)
 
 ###############################################################################
 
@@ -451,9 +508,9 @@ class FinIborDualCurve(FinDiscountCurve):
 
         for swap in self._usedSwaps:
             # We value it as of the start date of the swap
-            v = swap.value(swap._startDate, self._discountCurve, 
-                           self, None, principal=0.0)
-            v = v / swap._notional
+            v = swap.value(swap._effectiveDate, self._discountCurve, 
+                           self, None)
+            v = v / swap._fixedLeg._notional
             if abs(v) > swapTol:
                 print("Swap with maturity " + str(swap._maturityDate)
                       + " Not Repriced. Has Value", v)
@@ -488,7 +545,7 @@ class FinIborDualCurve(FinDiscountCurve):
 
         for i in range(0, numPoints):
             s += labelToString("% 10.6f" % self._times[i],
-                               "%12.10f" % self._dfValues[i])
+                               "%12.10f" % self._dfs[i])
         return s
 
 ###############################################################################
