@@ -5,15 +5,23 @@
 import numpy as np
 from scipy import optimize
 
+from scipy.interpolate import CubicSpline
+from scipy.interpolate import PchipInterpolator
+
+import copy
+
 from ...finutils.FinError import FinError
 from ...finutils.FinDate import FinDate
 from ...finutils.FinHelperFunctions import labelToString
 from ...finutils.FinHelperFunctions import checkArgumentTypes, _funcName
 from ...finutils.FinGlobalVariables import gDaysInYear
-from ...market.curves.FinInterpolate import FinInterpTypes
+from ...market.curves.FinInterpolator import FinInterpTypes, FinInterpolator
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
+from ...products.funding.FinIborDeposit import FinIborDeposit
+from ...products.funding.FinIborFRA import FinIborFRA
+from ...products.funding.FinIborSwap import FinIborSwap
 
-swaptol = 1e-8
+swaptol = 1e-10
 
 ##############################################################################
 # TODO: CHANGE times to dfTimes
@@ -21,14 +29,19 @@ swaptol = 1e-8
 
 
 def _f(df, *args):
-    ''' Root search objective function for swaps '''
+    ''' Root search objective function for IRS '''
+
     curve = args[0]
     valueDate = args[1]
     swap = args[2]
     numPoints = len(curve._times)
-    curve._dfValues[numPoints - 1] = df
-    v_swap = swap.value(valueDate, curve, curve, None, 1.0)
-    v_swap /= swap._notional
+    curve._dfs[numPoints - 1] = df
+
+    # For curves that need a fit function, we fit it now 
+    curve._interpolator.fit(curve._times, curve._dfs)     
+    v_swap = swap.value(valueDate, curve, curve, None)
+    notional = swap._fixedLeg._notional
+    v_swap /= notional    
     return v_swap
 
 ###############################################################################
@@ -36,20 +49,65 @@ def _f(df, *args):
 
 def _g(df, *args):
     ''' Root search objective function for swaps '''
-    liborCurve = args[0]
+    curve = args[0]
     valueDate = args[1]
     fra = args[2]
-    numPoints = len(liborCurve._times)
-    liborCurve._dfValues[numPoints - 1] = df
-    v_fra = fra.value(valueDate, liborCurve)
+    numPoints = len(curve._times)
+    curve._dfs[numPoints - 1] = df
+
+    # For curves that need a fit function, we fit it now 
+    curve._interpolator.fit(curve._times, curve._dfs)     
+    v_fra = fra.value(valueDate, curve)
     v_fra /= fra._notional
     return v_fra
 
 ###############################################################################
 
 
+def _costFunction(dfs, *args):
+    ''' Root search objective function for swaps '''
+
+#    print("Discount factors:", dfs)
+
+    liborCurve = args[0]
+    valuationDate = liborCurve._valuationDate
+    liborCurve._dfs = dfs
+    
+    times = liborCurve._times
+    values = -np.log(dfs)
+
+    # For curves that need a fit function, we fit it now 
+    liborCurve._interpolator.fit(liborCurve._times, liborCurve._dfs)
+
+    if liborCurve._interpType == FinInterpTypes.CUBIC_SPLINE_LOGDFS:
+        liborCurve._splineFunction = CubicSpline(times, values)
+    elif liborCurve._interpType == FinInterpTypes.PCHIP_CUBIC_SPLINE:
+        liborCurve._splineFunction = PchipInterpolator(times, values)
+
+    cost = 0.0
+    for depo in liborCurve._usedDeposits:
+        v = depo.value(valuationDate, liborCurve) / depo._notional
+#        print("DEPO:", depo._maturityDate, v)
+        cost += (v-1.0)**2
+
+    for fra in liborCurve._usedFRAs:
+        v = fra.value(valuationDate, liborCurve) / fra._notional
+#        print("FRA:", fra._maturityDate, v)
+        cost += v*v
+
+    for swap in liborCurve._usedSwaps:
+        v = swap.value(valuationDate, liborCurve) / swap._notional
+#        print("SWAP:", swap._maturityDate, v)
+        cost += v*v
+
+    print("Cost:", cost)
+    return cost
+
+###############################################################################
+
+
 class FinIborSingleCurve(FinDiscountCurve):
-    ''' Constructs a discount curve as implied by the prices of Ibor
+    ''' Constructs one discount and index curve as implied by prices of Ibor
     deposits, FRAs and IRS. Discounting is assumed to be at Libor and the value
     of the floating leg (including a notional) is assumed to be par. This 
     approach has been overtaken since 2008 as OIS discounting has become the
@@ -84,11 +142,11 @@ class FinIborSingleCurve(FinDiscountCurve):
 ###############################################################################
 
     def __init__(self,
-                 valuationDate: FinDate,
+                 valuationDate: FinDate, # This is the trade date (not T+2)
                  iborDeposits: list,
                  iborFRAs: list,
                  iborSwaps: list,
-                 interpType: FinInterpTypes = FinInterpTypes.LINEAR_SWAP_RATES,
+                 interpType: FinInterpTypes = FinInterpTypes.FLAT_FWD_RATES,
                  checkRefit: bool = False):  # Set to True to test it works
         ''' Create an instance of a FinIbor curve given a valuation date and
         a set of ibor deposits, ibor FRAs and iborSwaps. Some of these may
@@ -98,6 +156,8 @@ class FinIborSingleCurve(FinDiscountCurve):
         flat forwards between these coupon dates.
 
         The curve will assign a discount factor of 1.0 to the valuation date.
+        If no instrument is starting on the valuation date, the curve is then
+        assumed to be flat out to the first instrument using its zero rate.
         '''
 
         checkArgumentTypes(getattr(self, _funcName(), None), locals())
@@ -105,18 +165,16 @@ class FinIborSingleCurve(FinDiscountCurve):
         self._valuationDate = valuationDate
         self._validateInputs(iborDeposits, iborFRAs, iborSwaps)
         self._interpType = interpType
-        self._checkRefit = checkRefit
+        self._checkRefit = checkRefit        
+        self._interpolator = None
         self._buildCurve()
 
 ###############################################################################
 
     def _buildCurve(self):
         ''' Build curve based on interpolation. '''
-        
-        if self._interpType == FinInterpTypes.LINEAR_SWAP_RATES:
-            self._buildCurveLinearSwapRateInterpolation()
-        else:
-            self._buildCurveUsingSolver()
+
+        self._buildCurveUsing1DSolver()
 
 ###############################################################################
 
@@ -130,15 +188,29 @@ class FinIborSingleCurve(FinDiscountCurve):
         numFRAs = len(iborFRAs)
         numSwaps = len(iborSwaps)
 
+        depoStartDate = self._valuationDate
+        swapStartDate = self._valuationDate
+
         if numDepos + numFRAs + numSwaps == 0:
             raise FinError("No calibration instruments.")
 
         # Validation of the inputs.
         if numDepos > 0:
+            
+            depoStartDate = iborDeposits[0]._startDate
+
             for depo in iborDeposits:
-                startDt = depo._startDate
-                if startDt < self._valuationDate:
-                    raise FinError("First deposit starts before value date.")
+
+                if isinstance(depo, FinIborDeposit) is False:
+                    raise FinError("Deposit is not of type FinIborDeposit")
+
+                startDate = depo._startDate
+
+                if startDate < self._valuationDate:
+                    raise FinError("First deposit starts before valuation date.")
+
+                if startDate < depoStartDate:
+                    depoStartDate = startDate
 
             for depo in iborDeposits:
                 startDt = depo._startDate
@@ -148,21 +220,26 @@ class FinIborSingleCurve(FinDiscountCurve):
 
         # Ensure order of depos
         if numDepos > 1:
+            
             prevDt = iborDeposits[0]._maturityDate
-
             for depo in iborDeposits[1:]:
                 nextDt = depo._maturityDate
                 if nextDt <= prevDt:
                     raise FinError("Deposits must be in increasing maturity")
                 prevDt = nextDt
 
+        # REMOVED THIS AS WE WANT TO ANCHOR CURVE AT VALUATION DATE 
+        # USE A SYNTHETIC DEPOSIT TO BRIDGE GAP FROM VALUE DATE TO SETTLEMENT DATE
         # Ensure that valuation date is on or after first deposit start date
-        if numDepos > 1:
-            if iborDeposits[0]._startDate > self._valuationDate:
-                raise FinError("Valuation date must not be before first deposit settles.")
+        # if numDepos > 1:
+        #    if iborDeposits[0]._effectiveDate > self._valuationDate:
+        #        raise FinError("Valuation date must not be before first deposit settles.")
 
         if numFRAs > 0:
             for fra in iborFRAs:
+                if isinstance(fra, FinIborFRA) is False:
+                    raise FinError("FRA is not of type FinIborFRA")
+
                 startDt = fra._startDate
                 if startDt < self._valuationDate:
                     raise FinError("FRAs starts before valuation date")
@@ -176,17 +253,27 @@ class FinIborSingleCurve(FinDiscountCurve):
                 prevDt = nextDt
 
         if numSwaps > 0:
+
+            swapStartDate = iborSwaps[0]._effectiveDate
+
             for swap in iborSwaps:
-                startDt = swap._startDate
+
+                if isinstance(swap, FinIborSwap) is False: # is False and isinstance(swap, FinIborSwap) is False:
+                    raise FinError("Swap is not of type FinIborSwap")
+
+                startDt = swap._effectiveDate
                 if startDt < self._valuationDate:
                     raise FinError("Swaps starts before valuation date.")
 
+                if swap._effectiveDate < swapStartDate:
+                    swapStartDate = swap._effectiveDate
+
         if numSwaps > 1:
 
             # Swaps must all start on the same date for the bootstrap
-            startDt = iborSwaps[0]._startDate
+            startDt = iborSwaps[0]._effectiveDate
             for swap in iborSwaps[1:]:
-                nextStartDt = swap._startDate
+                nextStartDt = swap._effectiveDate
                 if nextStartDt != startDt:
                     raise FinError("Swaps must all have same start date.")
 
@@ -200,9 +287,13 @@ class FinIborSingleCurve(FinDiscountCurve):
 
             # Swaps must have same cashflows for bootstrap to work
             longestSwap = iborSwaps[-1]
-            longestSwapCpnDates = longestSwap._adjustedFixedDates
+            
+            longestSwapCpnDates = longestSwap._fixedLeg._paymentDates
+
             for swap in iborSwaps[0:-1]:
-                swapCpnDates = swap._adjustedFixedDates
+
+                swapCpnDates = swap._fixedLeg._paymentDates
+
                 numFlows = len(swapCpnDates)
                 for iFlow in range(0, numFlows):
                     if swapCpnDates[iFlow] != longestSwapCpnDates[iFlow]:
@@ -234,7 +325,24 @@ class FinIborSingleCurve(FinDiscountCurve):
 
         if numFRAs > 0 and numSwaps > 0:
             if firstSwapMaturityDate <= lastFRAMaturityDate:
-                raise FinError("First Swap must mature after last FRA")
+                raise FinError("First Swap must mature after last FRA ends")
+            
+        # If both depos and swaps start after T, we need a rate to get them to
+        # the first deposit. So we create a synthetic deposit rate contract.
+        
+        if swapStartDate > self._valuationDate:
+
+            if numDepos == 0:
+                raise FinError("Need a deposit rate to pin down short end.")
+
+            if depoStartDate > self._valuationDate:
+                firstDepo = iborDeposits[0]
+                if firstDepo._startDate > self._valuationDate:
+                    syntheticDeposit = copy.deepcopy(firstDepo)
+                    syntheticDeposit._startDate = self._valuationDate
+                    syntheticDeposit._maturityDate = firstDepo._startDate
+                    iborDeposits.insert(0, syntheticDeposit)
+                    numDepos += 1
 
         # Now determine which instruments are used
         self._usedDeposits = iborDeposits
@@ -244,27 +352,30 @@ class FinIborSingleCurve(FinDiscountCurve):
 
 ###############################################################################
 
-    def _buildCurveUsingSolver(self):
+    def _buildCurveUsing1DSolver(self):
         ''' Construct the discount curve using a bootstrap approach. This is
         the non-linear slower method that allows the user to choose a number
         of interpolation approaches between the swap rates and other rates. It
         involves the use of a solver. '''
 
+        self._interpolator = FinInterpolator(self._interpType)
         self._times = np.array([])
-        self._dfValues = np.array([])
+        self._dfs = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfValues = np.append(self._dfValues, dfMat)
+        self._dfs = np.append(self._dfs, dfMat)
+        self._interpolator.fit(self._times, self._dfs)
 
         for depo in self._usedDeposits:
             dfSettle = self.df(depo._startDate)
             dfMat = depo._maturityDf() * dfSettle
             tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
+            self._interpolator.fit(self._times, self._dfs)
 
         oldtmat = tmat
 
@@ -279,11 +390,10 @@ class FinIborSingleCurve(FinDiscountCurve):
             if tset < oldtmat and tmat > oldtmat:
                 dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
-
+                self._dfs = np.append(self._dfs, dfMat)
                 argtuple = (self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
                                         args=argtuple, tol=swaptol,
@@ -292,11 +402,11 @@ class FinIborSingleCurve(FinDiscountCurve):
         for swap in self._usedSwaps:
             # I use the lastPaymentDate in case a date has been adjusted fwd
             # over a holiday as the maturity date is usually not adjusted CHECK
-            maturityDate = swap._lastPaymentDate
+            maturityDate = swap._fixedLeg._paymentDates[-1]
             tmat = (maturityDate - self._valuationDate) / gDaysInYear
 
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
 
             argtuple = (self, self._valuationDate, swap)
 
@@ -307,6 +417,44 @@ class FinIborSingleCurve(FinDiscountCurve):
         if self._checkRefit is True:
             self._checkRefits(1e-10, swaptol, 1e-5)
 
+###############################################################################
+
+    def _buildCurveUsingQuadraticMinimiser(self):
+        ''' Construct the discount curve using a minimisation approach. This is
+        the This enables a more complex interpolation scheme. '''
+
+        tmat = 0.0
+        dfMat = 1.0
+
+        gridTimes = [tmat]
+        gridDfs = [dfMat]
+
+        for depo in self._usedDeposits:
+            tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
+            gridTimes.append(tmat)
+
+        for fra in self._usedFRAs:
+            tmat = (fra._maturityDate - self._valuationDate) / gDaysInYear
+            gridTimes.append(tmat)
+            gridDfs.append(dfMat)
+
+        for swap in self._usedSwaps:
+            tmat = (swap._maturityDate - self._valuationDate) / gDaysInYear
+            gridTimes.append(tmat)
+
+        self._times = np.array(gridTimes)
+        self._dfs = np.exp(-self._times * 0.05)
+        
+        argtuple = (self)
+
+        res = optimize.minimize(_costFunction, self._dfs, method = 'BFGS',
+                                args = argtuple, options = {'gtol':1e-3})    
+
+        self._dfs = np.array(res.x)
+
+        if self._checkRefit is True:
+            self._checkRefits(1e-10, swaptol, 1e-5)
+
 ###############################################################################
 
     def _buildCurveLinearSwapRateInterpolation(self):
@@ -314,21 +462,25 @@ class FinIborSingleCurve(FinDiscountCurve):
         the linear swap rate method that is fast and exact as it does not
         require the use of a solver. It is also market standard. '''
 
+        self._interpolator = FinInterpolator(self._interpType)
+
         self._times = np.array([])
-        self._dfValues = np.array([])
+        self._dfs = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfValues = np.append(self._dfValues, dfMat)
+        self._dfs = np.append(self._dfs, dfMat)
+        self._interpolator.fit(self._times, self._dfs)
 
         for depo in self._usedDeposits:
             dfSettle = self.df(depo._startDate)
             dfMat = depo._maturityDf() * dfSettle
             tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
+            self._interpolator.fit(self._times, self._dfs)
 
         oldtmat = tmat
 
@@ -343,10 +495,13 @@ class FinIborSingleCurve(FinDiscountCurve):
             if tset < oldtmat and tmat > oldtmat:
                 dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
+                self._interpolator.fit(self._times, self._dfs)
+
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
+                self._interpolator.fit(self._times, self._dfs)
 
                 argtuple = (self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
@@ -395,7 +550,7 @@ class FinIborSingleCurve(FinDiscountCurve):
         # may be different from the maturity date due to a holiday adjustment
         # and the swap rates need to align with the coupon payment dates
         for swap in self._usedSwaps:
-            swapRate = swap._fixedCoupon
+            swapRate = swap._fixedLeg._coupon
             maturityDate = swap._adjustedFixedDates[-1]
             tswap = (maturityDate - self._valuationDate) / gDaysInYear
             swapTimes.append(tswap)
@@ -418,7 +573,7 @@ class FinIborSingleCurve(FinDiscountCurve):
         acc = 0.0
         df = 1.0
         pv01 = 0.0
-        dfSettle = self.df(longestSwap._startDate)
+        dfSettle = self.df(longestSwap._effectiveDate)
 
         for i in range(1, startIndex):
             dt = couponDates[i]
@@ -437,7 +592,8 @@ class FinIborSingleCurve(FinDiscountCurve):
             dfMat = (dfSettle - swapRate * pv01) / pv01End
 
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
+            self._interpolator.fit(self._times, self._dfs)
 
             pv01 += acc * dfMat
 
@@ -462,8 +618,8 @@ class FinIborSingleCurve(FinDiscountCurve):
 
         for swap in self._usedSwaps:
             # We value it as of the start date of the swap
-            v = swap.value(swap._startDate, self, self, None, principal=0.0)
-            v = v / swap._notional
+            v = swap.value(swap._effectiveDate, self, self, None)
+            v = v / swap._fixedLeg._notional
 #            print("REFIT SWAP VALUATION:", swap._adjustedMaturityDate, v)
             if abs(v) > swapTol:
                 print("Swap with maturity " + str(swap._maturityDate)
@@ -473,7 +629,7 @@ class FinIborSingleCurve(FinDiscountCurve):
                 raise FinError("Swap not repriced.")
 
 ###############################################################################
-
+        
     def __repr__(self):
         ''' Print out the details of the Ibor curve. '''
 
@@ -499,7 +655,7 @@ class FinIborSingleCurve(FinDiscountCurve):
         s += labelToString("GRID TIMES", "GRID DFS")
         for i in range(0, numPoints):
             s += labelToString("% 10.6f" % self._times[i],
-                               "%12.10f" % self._dfValues[i])
+                               "%12.10f" % self._dfs[i])
 
         return s
 
