@@ -4,16 +4,20 @@
 
 import numpy as np
 from scipy import optimize
+import copy
 
 from ...finutils.FinError import FinError
 from ...finutils.FinDate import FinDate
-from ...finutils.FinHelperFunctions import labelToString, gridIndex
+from ...finutils.FinHelperFunctions import labelToString
 from ...finutils.FinHelperFunctions import checkArgumentTypes, _funcName
 from ...finutils.FinGlobalVariables import gDaysInYear
-from ...market.curves.FinInterpolate import FinInterpTypes
+from ...market.curves.FinInterpolator import FinInterpTypes, FinInterpolator
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
-from ...finutils.FinDayCount import FinDayCountTypes
-swaptol = 1e-8
+
+from ...products.funding.FinIborDeposit import FinIborDeposit
+from ...products.funding.FinOIS import FinOIS
+
+swaptol = 1e-10
 
 ##############################################################################
 # TODO: CHANGE times to dfTimes
@@ -46,14 +50,19 @@ def _fois(oir, *args):
 ###############################################################################
 
 def _f(df, *args):
-    ''' Root search objective function for swaps '''
+    ''' Root search objective function for OIS '''
+
     curve = args[0]
     valueDate = args[1]
     swap = args[2]
     numPoints = len(curve._times)
-    curve._dfValues[numPoints - 1] = df
-    v_swap = swap.value(valueDate, curve, None, 1.0)
-    v_swap /= swap._notional
+    curve._dfs[numPoints - 1] = df
+
+    # For curves that need a fit function, we fit it now 
+    curve._interpolator.fit(curve._times, curve._dfs)     
+    v_swap = swap.value(valueDate, curve, None)
+    notional = swap._fixedLeg._notional
+    v_swap /= notional
     return v_swap
 
 ###############################################################################
@@ -65,7 +74,10 @@ def _g(df, *args):
     valueDate = args[1]
     fra = args[2]
     numPoints = len(curve._times)
-    curve._dfValues[numPoints - 1] = df
+    curve._dfs[numPoints - 1] = df
+
+    # For curves that need a fit function, we fit it now 
+    curve._interpolator.fit(curve._times, curve._dfs)     
     v_fra = fra.value(valueDate, curve)
     v_fra /= fra._notional
     return v_fra
@@ -93,7 +105,7 @@ class FinOISCurve(FinDiscountCurve):
                  oisDeposits: list,
                  oisFRAs: list,
                  oisSwaps: list,
-                 interpType: FinInterpTypes = FinInterpTypes.LINEAR_SWAP_RATES,
+                 interpType: FinInterpTypes = FinInterpTypes.FLAT_FWD_RATES,
                  checkRefit: bool = False):  # Set to True to test it works
         ''' Create an instance of an overnight index rate swap curve given a
         valuation date and a set of OIS rates. Some of these may
@@ -111,6 +123,7 @@ class FinOISCurve(FinDiscountCurve):
         self._validateInputs(oisDeposits, oisFRAs, oisSwaps)
         self._interpType = interpType
         self._checkRefit = checkRefit
+        self._interpolator = None
         self._buildCurve()
 
 ###############################################################################
@@ -118,10 +131,7 @@ class FinOISCurve(FinDiscountCurve):
     def _buildCurve(self):
         ''' Build curve based on interpolation. '''
             
-        if self._interpType == FinInterpTypes.LINEAR_SWAP_RATES:
-            self._buildCurveLinearSwapRateInterpolation()
-        else:
-            self._buildCurveUsingSolver()
+        self._buildCurveUsing1DSolver()
 
 ###############################################################################
 
@@ -135,16 +145,30 @@ class FinOISCurve(FinDiscountCurve):
         numFRAs = len(oisFRAs)
         numSwaps = len(oisSwaps)
 
+        depoStartDate = self._valuationDate
+        swapStartDate = self._valuationDate
+
         if numDepos + numFRAs + numSwaps == 0:
             raise FinError("No calibration instruments.")
 
         # Validation of the inputs.
         if numDepos > 0:
+
+            depoStartDate = oisDeposits[0]._startDate
+
             for depo in oisDeposits:
-                startDt = depo._startDate
-                if startDt < self._valuationDate:
+
+                if isinstance(depo, FinIborDeposit) is False:
+                    raise FinError("Deposit is not of type FinIborDeposit")
+
+                startDate = depo._startDate
+
+                if startDate < self._valuationDate:
                     raise FinError("First deposit starts before value date.")
 
+                if startDate < depoStartDate:
+                    depoStartDate = startDate
+
             for depo in oisDeposits:
                 startDt = depo._startDate
                 endDt = depo._maturityDate
@@ -153,19 +177,21 @@ class FinOISCurve(FinDiscountCurve):
 
         # Ensure order of depos
         if numDepos > 1:
-            prevDt = oisDeposits[0]._maturityDate
 
+            prevDt = oisDeposits[0]._maturityDate
             for depo in oisDeposits[1:]:
                 nextDt = depo._maturityDate
                 if nextDt <= prevDt:
                     raise FinError("Deposits must be in increasing maturity")
                 prevDt = nextDt
 
+        # REMOVED THIS AS WE WANT TO ANCHOR CURVE AT VALUATION DATE 
+        # USE A SYNTHETIC DEPOSIT TO BRIDGE GAP FROM VALUE DATE TO SETTLEMENT DATE
         # Ensure that valuation date is on or after first deposit start date
-        if numDepos > 1:
-            if oisDeposits[0]._startDate > self._valuationDate:
-                raise FinError("Valuation date must not be before first deposit settles.")
-
+        # Ensure that valuation date is on or after first deposit start date
+        # if numDepos > 1:
+        #    if oisDeposits[0]._startDate > self._valuationDate:
+        #        raise FinError("Valuation date must not be before first deposit settles.")
 
         # Validation of the inputs.
         if numFRAs > 0:
@@ -174,6 +200,10 @@ class FinOISCurve(FinDiscountCurve):
                 if startDt <= self._valuationDate:
                     raise FinError("FRAs starts before valuation date")
 
+                startDt = fra._startDate
+                if startDt < self._valuationDate:
+                    raise FinError("FRAs starts before valuation date")
+
         if numFRAs > 1:
             prevDt = oisFRAs[0]._maturityDate
             for fra in oisFRAs[1:]:
@@ -183,19 +213,22 @@ class FinOISCurve(FinDiscountCurve):
                 prevDt = nextDt
 
         if numSwaps > 0:
+
+            swapStartDate = oisSwaps[0]._effectiveDate
+
             for swap in oisSwaps:
-                startDt = swap._startDate
+
+                if isinstance(swap, FinOIS) is False:
+                    raise FinError("Swap is not of type FinOIS")
+
+                startDt = swap._effectiveDate
                 if startDt < self._valuationDate:
                     raise FinError("Swaps starts before valuation date.")
 
-        if numSwaps > 1:
+                if swap._effectiveDate < swapStartDate:
+                    swapStartDate = swap._effectiveDate
 
-            # Swaps must all start on the same date for the bootstrap
-#            startDt = oisSwaps[0]._startDate
-#            for swap in oisSwaps[1:]:
-#                nextStartDt = swap._startDate
-#                if nextStartDt != startDt:
-#                    raise FinError("Swaps must all have same start date.")
+        if numSwaps > 1:
 
             # Swaps must be increasing in tenor/maturity
             prevDt = oisSwaps[0]._maturityDate
@@ -205,6 +238,7 @@ class FinOISCurve(FinDiscountCurve):
                     raise FinError("Swaps must be in increasing maturity")
                 prevDt = nextDt
 
+        # TODO: REINSTATE THESE CHECKS ?
             # Swaps must have same cashflows for linear swap bootstrap to work
 #            longestSwap = oisSwaps[-1]
 #            longestSwapCpnDates = longestSwap._adjustedFixedDates
@@ -219,114 +253,81 @@ class FinOISCurve(FinDiscountCurve):
         # Now we have ensure they are in order check for overlaps and the like
         #######################################################################
 
+        lastDepositMaturityDate = FinDate(1, 1, 1900)
+        firstFRAMaturityDate = FinDate(1, 1, 1900)
         lastFRAMaturityDate = FinDate(1, 1, 1900)
 
+        if numDepos > 0:
+            lastDepositMaturityDate = oisDeposits[-1]._maturityDate
+
         if numFRAs > 0:
+            firstFRAMaturityDate = oisFRAs[0]._maturityDate
             lastFRAMaturityDate = oisFRAs[-1]._maturityDate
 
         if numSwaps > 0:
             firstSwapMaturityDate = oisSwaps[0]._maturityDate
 
+        if numFRAs > 0 and numSwaps > 0:
+            if firstSwapMaturityDate <= lastFRAMaturityDate:
+                raise FinError("First Swap must mature after last FRA ends")
+
+        if numDepos > 0 and numFRAs > 0:
+            if firstFRAMaturityDate <= lastDepositMaturityDate:
+                print("FRA Maturity Date:", firstFRAMaturityDate)
+                print("Last Deposit Date:", lastDepositMaturityDate)
+                raise FinError("First FRA must end after last Deposit")
+
         if numFRAs > 0 and numSwaps > 0:
             if firstSwapMaturityDate <= lastFRAMaturityDate:
                 raise FinError("First Swap must mature after last FRA")
 
+        if swapStartDate > self._valuationDate:
+
+            if numDepos == 0:
+                raise FinError("Need a deposit rate to pin down short end.")
+
+            if depoStartDate > self._valuationDate:
+                firstDepo = oisDeposits[0]
+                if firstDepo._startDate > self._valuationDate:
+                    print("Inserting synthetic deposit")
+                    syntheticDeposit = copy.deepcopy(firstDepo)
+                    syntheticDeposit._startDate = self._valuationDate
+                    syntheticDeposit._maturityDate = firstDepo._startDate
+                    oisDeposits.insert(0, syntheticDeposit)
+                    numDepos += 1
+
         # Now determine which instruments are used
-        self._usedDeposits = []
+        self._usedDeposits = oisDeposits
         self._usedFRAs = oisFRAs
         self._usedSwaps = oisSwaps
-        
         self._dayCountType = None
 
 ###############################################################################
 
-    # def _buildCurveUsingLinAlg(self):
-    #     ''' Construct the discount curve using a linear algebra approach. This
-    #     is exact and allows spot and forward starting OIS to be fitted. It also
-    #     handles FRA contracts. '''
-
-    #     numInstruments = len(self._usedFRAs) + len(self._usedSwaps)
-
-    #     # generate the time grid - start with today
-    #     gridTimes = [0.0]
-
-    #     for fra in self._usedFRAs:
-    #         tset = (fra._startDate - self._valuationDate) / gDaysInYear
-    #         tmat = (fra._maturityDate - self._valuationDate) / gDaysInYear
-    #         gridTimes.append(tset)
-    #         gridTimes.append(tmat)
-
-    #     for swap in self._usedSwaps:
-    #         for fixedFlowDate in swap._adjustedFixedDates:
-    #             tflow = (fixedFlowDate - self._valuationDate) / gDaysInYear
-    #             gridTimes.append(tflow)
-
-    #     gridTimes = list(sorted(set(gridTimes)))
-    #     numTimes = len(gridTimes)
-        
-    #     flows = np.zeros(shape=(numInstruments, numTimes))
-    #     rhs = np.zeros(shape=(numInstruments,1))
-
-    #     instrumentCounter = 0        
-    #     for fra in self._usedFRAs:
-    #         tset = (fra._startDate - self._valuationDate) / gDaysInYear
-    #         tmat = (fra._maturityDate - self._valuationDate) / gDaysInYear
-    #         iset = gridIndex(tset, gridTimes)
-    #         imat = gridIndex(tset, gridTimes)
-    #         flows[instrumentCounter, iset] += -1.0
-    #         flows[instrumentCounter, imat] += 1.0 + fra._fraRate
-    #         rhs[instrumentCounter] = 0
-    #         instrumentCounter += 1
-
-    #     for swap in self._usedSwaps:
-    #         for fixedFlowDate in swap._adjustedFixedDates:
-    #             tflow = (fixedFlowDate - self._valuationDate) / gDaysInYear
-    #             iFlow = gridIndex(tflow, gridTimes)
-    #             accFactor = 1.0
-    #             flows[instrumentCounter][iFlow] = swap._fixedCoupon * accFactor
-
-    #         tmat = (swap._maturityDate - self._valuationDate) / gDaysInYear
-    #         imat = gridIndex(tmat, gridTimes)
-    #         flows[instrumentCounter, imat] += 1.0
-    #         rhs[instrumentCounter] = 1.0
-    #         instrumentCounter += 1
-            
-    #     print(flows)
-    #     print(rhs)
-        
-    #     print(flows.shape)
-    #     print(rhs.shape)
-        
-    #     dfs = np.linalg.solve(flows, rhs)
-    #     self._times = gridTimes
-    #     self._dfValues = dfs
-
-    #     if self._checkRefit is True:
-    #         self._checkRefits(1e-10, swaptol, 1e-5)
-
-###############################################################################
-
-    def _buildCurveUsingSolver(self):
+    def _buildCurveUsing1DSolver(self):
         ''' Construct the discount curve using a bootstrap approach. This is
         the non-linear slower method that allows the user to choose a number
         of interpolation approaches between the swap rates and other rates. It
         involves the use of a solver. '''
 
+        self._interpolator = FinInterpolator(self._interpType)
         self._times = np.array([])
-        self._dfValues = np.array([])
+        self._dfs = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfValues = np.append(self._dfValues, dfMat)
+        self._dfs = np.append(self._dfs, dfMat)
+        self._interpolator.fit(self._times, self._dfs)
 
         for depo in self._usedDeposits:
             dfSettle = self.df(depo._startDate)
             dfMat = depo._maturityDf() * dfSettle
             tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
+            self._interpolator.fit(self._times, self._dfs)
 
         oldtmat = tmat
 
@@ -341,11 +342,10 @@ class FinOISCurve(FinDiscountCurve):
             if tset < oldtmat and tmat > oldtmat:
                 dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
-
+                self._dfs = np.append(self._dfs, dfMat)
                 argtuple = (self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
                                         args=argtuple, tol=swaptol,
@@ -354,11 +354,11 @@ class FinOISCurve(FinDiscountCurve):
         for swap in self._usedSwaps:
             # I use the lastPaymentDate in case a date has been adjusted fwd
             # over a holiday as the maturity date is usually not adjusted CHECK
-            maturityDate = swap._lastPaymentDate
+            maturityDate = swap._fixedLeg._paymentDates[-1]
             tmat = (maturityDate - self._valuationDate) / gDaysInYear
 
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
 
             argtuple = (self, self._valuationDate, swap)
 
@@ -376,21 +376,24 @@ class FinOISCurve(FinDiscountCurve):
         the linear swap rate method that is fast and exact as it does not
         require the use of a solver. It is also market standard. '''
 
+        self._interpolator = FinInterpolator(self._interpType)
+
         self._times = np.array([])
-        self._dfValues = np.array([])
+        self._dfs = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfValues = np.append(self._dfValues, dfMat)
+        self._dfs = np.append(self._dfs, dfMat)
 
         for depo in self._usedDeposits:
             dfSettle = self.df(depo._startDate)
             dfMat = depo._maturityDf() * dfSettle
             tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
+            self._interpolator.fit(self._times, self._dfs)
 
         oldtmat = tmat
 
@@ -405,10 +408,12 @@ class FinOISCurve(FinDiscountCurve):
             if tset < oldtmat and tmat > oldtmat:
                 dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
+                self._interpolator.fit(self._times, self._dfs)
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfValues = np.append(self._dfValues, dfMat)
+                self._dfs = np.append(self._dfs, dfMat)
+                self._interpolator.fit(self._times, self._dfs)
 
                 argtuple = (self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
@@ -499,7 +504,8 @@ class FinOISCurve(FinDiscountCurve):
             dfMat = (dfSettle - swapRate * pv01) / pv01End
 
             self._times = np.append(self._times, tmat)
-            self._dfValues = np.append(self._dfValues, dfMat)
+            self._dfs = np.append(self._dfs, dfMat)
+            self._interpolator.fit(self._times, self._dfs)
 
             pv01 += acc * dfMat
 
@@ -519,7 +525,7 @@ class FinOISCurve(FinDiscountCurve):
 
         for swap in self._usedSwaps:
             # We value it as of the start date of the swap
-            v = swap.value(swap._startDate, self, self, None, principal=0.0)
+            v = swap.value(swap._effectiveDate, self, self, None, principal=0.0)
             v = v / swap._notional
             if abs(v) > swapTol:
                 print("Swap with maturity " + str(swap._maturityDate)
@@ -594,6 +600,10 @@ class FinOISCurve(FinDiscountCurve):
         s = labelToString("OBJECT TYPE", type(self).__name__)
         s += labelToString("VALUATION DATE", self._valuationDate)
 
+        for depo in self._usedDeposits:
+            s += labelToString("DEPOSIT", "")
+            s += depo.__repr__()
+
         for fra in self._usedFRAs:
             s += labelToString("FRA", "")
             s += fra.__repr__()
@@ -609,7 +619,7 @@ class FinOISCurve(FinDiscountCurve):
         s += labelToString("GRID TIMES", "GRID DFS")
         for i in range(0, numPoints):
             s += labelToString("% 10.6f" % self._times[i],
-                               "%12.10f" % self._dfValues[i])
+                               "%12.10f" % self._dfs[i])
 
         return s
 
