@@ -14,7 +14,7 @@ from ...finutils.FinDate import FinDate
 from ...products.fx.FinFXModelTypes import FinFXModel
 from ...products.fx.FinFXModelTypes import FinFXModelBlackScholes
 from ...finutils.FinHelperFunctions import labelToString, checkArgumentTypes
-from ...finutils.FinOptionTypes import FinOptionTypes
+from ...finutils.FinGlobalTypes import FinOptionTypes
 
 ###############################################################################
 
@@ -65,7 +65,7 @@ class FinFXDigitalOption():
         domestic or foreign currency. '''
 
         if type(valueDate) == FinDate:
-            spotDate = valueDate.addWorkDays(self._spotDays)
+            spotDate = valueDate.addWeekDays(self._spotDays)
             tdel = (self._deliveryDate - spotDate) / gDaysInYear
             texp = (self._expiryDate - valueDate) / gDaysInYear
         else:
