@@ -3,11 +3,14 @@
 ###############################################################################
 
 import time
-from FinTestCases import FinTestCases, globalTestCaseMode
+import numpy as np
+
+import sys
+sys.path.append("..")
 
 from financepy.products.credit.FinCDS import FinCDS
 from financepy.finutils.FinMath import ONE_MILLION
-from financepy.market.curves.FinInterpolate import FinInterpTypes
+from financepy.market.curves.FinInterpolator import FinInterpTypes
 from financepy.products.funding.FinIborSwap import FinIborSwap
 from financepy.products.funding.FinIborDeposit import FinIborDeposit
 from financepy.market.curves.FinDiscountCurve import FinDiscountCurve
@@ -22,11 +25,7 @@ from financepy.finutils.FinDayCount import FinDayCountTypes
 from financepy.finutils.FinDate import FinDate
 from financepy.finutils.FinGlobalTypes import FinSwapTypes
 
-import numpy as np
-import sys
-sys.path.append("..//..")
-
-
+from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
 ##########################################################################
@@ -47,7 +46,7 @@ def test_CDSFastApproximation():
     liborCurve = FinDiscountCurve(valueDate,
                                   dates,
                                   discountFactors,
-                                  FinInterpTypes.FLAT_FORWARDS)
+                                  FinInterpTypes.FLAT_FWD_RATES)
 
     ##########################################################################
 
@@ -121,7 +120,7 @@ def test_IssuerCurveBuild():
     ''' Test issuer curve build with simple libor curve to isolate cds
     curve building time cost. '''
 
-    valuationDate = FinDate(2018, 6, 20)
+    valuationDate = FinDate(20, 6, 2018)
 
     times = np.linspace(0.0, 10.0, 11)
     r = 0.05
@@ -130,7 +129,7 @@ def test_IssuerCurveBuild():
     liborCurve = FinDiscountCurve(valuationDate,
                                   dates,
                                   discountFactors,
-                                  FinInterpTypes.FLAT_FORWARDS)
+                                  FinInterpTypes.FLAT_FWD_RATES)
     recoveryRate = 0.40
 
     cdsContracts = []
@@ -183,10 +182,12 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     tradeDate = FinDate(2019, 8, 9)
     valuationDate = tradeDate.addDays(1)
 
+    m = 1.0  # 0.00000000000
+
     dcType = FinDayCountTypes.ACT_360
     depos = []
-
-    m = 1.0  # 0.00000000000
+    depo1 = FinIborDeposit(valuationDate, "1D", m * 0.0220, dcType)
+    depos.append(depo1)
 
     spotDays = 2
     settlementDate = valuationDate.addDays(spotDays)
@@ -222,7 +223,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap1 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.015910 + irBump,
         fixedFreq,
         dcType)
@@ -232,7 +233,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap2 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.014990 + irBump,
         fixedFreq,
         dcType)
@@ -242,7 +243,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap3 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.014725 + irBump,
         fixedFreq,
         dcType)
@@ -252,7 +253,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap4 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.014640 + irBump,
         fixedFreq,
         dcType)
@@ -262,7 +263,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap5 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.014800 + irBump,
         fixedFreq,
         dcType)
@@ -272,7 +273,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap6 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.014995 + irBump,
         fixedFreq,
         dcType)
@@ -282,7 +283,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap7 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.015180 + irBump,
         fixedFreq,
         dcType)
@@ -292,7 +293,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap8 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.015610 + irBump,
         fixedFreq,
         dcType)
@@ -302,7 +303,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap9 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.015880 + irBump,
         fixedFreq,
         dcType)
@@ -312,13 +313,13 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
     swap10 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.016430 + irBump,
         fixedFreq,
         dcType)
     swaps.append(swap10)
 
-    liborCurve = FinIborSingleCurve(settlementDate, depos, fras, swaps)
+    liborCurve = FinIborSingleCurve(valuationDate, depos, fras, swaps)
 
     cdsMarketContracts = []
 
@@ -362,7 +363,7 @@ def buildFullIssuerCurve1(mktSpreadBump, irBump):
 
     recoveryRate = 0.40
 
-    issuerCurve = FinCDSCurve(settlementDate,
+    issuerCurve = FinCDSCurve(valuationDate,
                               cdsMarketContracts,
                               liborCurve,
                               recoveryRate)
@@ -381,11 +382,11 @@ def test_fullPriceCDS1():
     liborCurve, issuerCurve = buildFullIssuerCurve1(0.0, 0.0)
 
     # This is the 10 year contract at an off market coupon
-    maturityDate = FinDate(2029, 6, 20)
+    maturityDate = FinDate(20, 6, 2029)
     cdsCoupon = 0.0150
     notional = ONE_MILLION
-    longProtection = False
-    tradeDate = FinDate(2019, 8, 9)
+    longProtection = True
+    tradeDate = FinDate(9, 8, 2019)
     valuationDate = tradeDate.addDays(1)
     effectiveDate = valuationDate
 
@@ -411,6 +412,8 @@ def test_fullPriceCDS1():
     p = cdsContract.cleanPrice(valuationDate, issuerCurve, cdsRecovery)
     testCases.print("CLEAN_PRICE", p)
 
+    # MARKIT PRICE IS 168517
+    
     accruedDays = cdsContract.accruedDays()
     testCases.print("ACCRUED_DAYS", accruedDays)
 
@@ -467,6 +470,7 @@ def buildFullIssuerCurve2(mktSpreadBump, irBump):
 
     m = 1.0
 
+    valuationDate = FinDate(24, 8, 2020)
     settlementDate = FinDate(24, 8, 2020)
     dcType = FinDayCountTypes.ACT_360
     depos = []
@@ -500,7 +504,7 @@ def buildFullIssuerCurve2(mktSpreadBump, irBump):
     swap1 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.002155 + irBump,
         fixedFreq,
         dcType)
@@ -510,7 +514,7 @@ def buildFullIssuerCurve2(mktSpreadBump, irBump):
     swap2 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.002305 + irBump,
         fixedFreq,
         dcType)
@@ -520,7 +524,7 @@ def buildFullIssuerCurve2(mktSpreadBump, irBump):
     swap3 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.002665 + irBump,
         fixedFreq,
         dcType)
@@ -530,13 +534,13 @@ def buildFullIssuerCurve2(mktSpreadBump, irBump):
     swap4 = FinIborSwap(
         settlementDate,
         maturityDate,
-        FinSwapTypes.PAYER,
+        FinSwapTypes.PAY,
         m * 0.003290 + irBump,
         fixedFreq,
         dcType)
     swaps.append(swap4)
 
-    liborCurve = FinIborSingleCurve(settlementDate, depos, [], swaps)
+    liborCurve = FinIborSingleCurve(valuationDate, depos, [], swaps)
 
     cdsCoupon = 0.01 + mktSpreadBump
 
