@@ -2,25 +2,26 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
+import numpy as np
+
+import sys
+sys.path.append("..")
+
 from financepy.market.curves.FinDiscountCurvePoly import FinDiscountCurvePoly
 from financepy.finutils.FinDate import FinDate
-import numpy as np
-import sys
-sys.path.append("..//..")
 
-##########################################################################
+from FinTestCases import FinTestCases, globalTestCaseMode
+testCases = FinTestCases(__file__, globalTestCaseMode)
+
+##############################################################################
 # TODO
 # Inherit from FinDiscountCurve and add df method
 # Put in a convention for the rate
 # Use Frequency object
-##########################################################################
+##############################################################################
 
 PLOT_GRAPHS = False
 
-testCases = FinTestCases(__file__, globalTestCaseMode)
-
-
 def test_FinDiscountCurvePolynomial():
 
     times = np.linspace(0.00, 10.0, 21)
