@@ -4,7 +4,8 @@
 
 import numpy as np
 
-from FinTestCases import FinTestCases, globalTestCaseMode
+import sys
+sys.path.append("..")
 
 from financepy.finutils.FinDate import FinDate
 from financepy.finutils.FinDayCount import FinDayCountTypes
@@ -26,8 +27,9 @@ from financepy.models.FinModelRatesBDT import FinModelRatesBDT
 from financepy.products.funding.FinIborSingleCurve import FinIborSingleCurve
 from financepy.market.curves.FinDiscountCurveFlat import FinDiscountCurveFlat
 from financepy.market.curves.FinDiscountCurveZeros import FinDiscountCurveZeros
-from financepy.market.curves.FinInterpolate import FinInterpTypes
+from financepy.market.curves.FinInterpolator import FinInterpTypes
 
+from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
 ###############################################################################
@@ -55,18 +57,18 @@ def test_FinIborDepositsAndSwaps(valuationDate):
     swaps = []
     fixedBasis = FinDayCountTypes.ACT_365F
     fixedFreq = FinFrequencyTypes.SEMI_ANNUAL
-    swapType = FinSwapTypes.PAYER
+    fixedLegType = FinSwapTypes.PAY
     
     swapRate = 0.05
-    swap1 = FinIborSwap(settlementDate, "1Y",  swapType, swapRate, fixedFreq, fixedBasis)
-    swap2 = FinIborSwap(settlementDate, "3Y",  swapType, swapRate, fixedFreq, fixedBasis)
-    swap3 = FinIborSwap(settlementDate, "5Y",  swapType, swapRate, fixedFreq, fixedBasis)
+    swap1 = FinIborSwap(settlementDate, "1Y",  fixedLegType, swapRate, fixedFreq, fixedBasis)
+    swap2 = FinIborSwap(settlementDate, "3Y",  fixedLegType, swapRate, fixedFreq, fixedBasis)
+    swap3 = FinIborSwap(settlementDate, "5Y",  fixedLegType, swapRate, fixedFreq, fixedBasis)
 
     swaps.append(swap1)
     swaps.append(swap2)
     swaps.append(swap3)
 
-    liborCurve = FinIborSingleCurve(settlementDate, depos, fras, swaps)
+    liborCurve = FinIborSingleCurve(valuationDate, depos, fras, swaps)
 
     return liborCurve
 
@@ -103,7 +105,7 @@ def testFinIborSwaptionModels():
     settlementDate = valuationDate.addWeekDays(2)
 
     for k in strikes:
-        swaptionType = FinSwapTypes.PAYER
+        swaptionType = FinSwapTypes.PAY
         swaption = FinIborSwaption(settlementDate,
                                    exerciseDate,
                                    swapMaturityDate,
@@ -124,7 +126,7 @@ def testFinIborSwaptionModels():
                      "SABR_SHFTD", "HW", "BK")
 
     for k in strikes:
-        swaptionType = FinSwapTypes.RECEIVER
+        swaptionType = FinSwapTypes.RECEIVE
         swaption = FinIborSwaption(settlementDate,
                                     exerciseDate,
                                     swapMaturityDate,
@@ -146,7 +148,7 @@ def testFinIborSwaptionModels():
 
 def test_FinIborSwaptionQLExample():
 
-    #   valuationDate = FinDate(28, 2, 2014)
+    valuationDate = FinDate(4, 3, 2014)
     settlementDate = FinDate(4, 3, 2014)
 
     depoDCCType = FinDayCountTypes.THIRTY_E_360_ISDA
@@ -165,34 +167,34 @@ def test_FinIborSwaptionQLExample():
     swaps = []
     accType = FinDayCountTypes.ACT_365F
     fixedFreqType = FinFrequencyTypes.SEMI_ANNUAL
-    swapType = FinSwapTypes.PAYER
+    fixedLegType = FinSwapTypes.PAY
     
-    swap = FinIborSwap(settlementDate, "3Y", swapType, 0.00790, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "3Y", fixedLegType, 0.00790, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "4Y", swapType, 0.01200, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "4Y", fixedLegType, 0.01200, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "5Y", swapType, 0.01570, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "5Y", fixedLegType, 0.01570, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "6Y", swapType, 0.01865, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "6Y", fixedLegType, 0.01865, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "7Y", swapType, 0.02160, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "7Y", fixedLegType, 0.02160, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "8Y", swapType, 0.02350, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "8Y", fixedLegType, 0.02350, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "9Y", swapType, 0.02540, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "9Y", fixedLegType, 0.02540, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "10Y", swapType, 0.0273, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "10Y", fixedLegType, 0.0273, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "15Y", swapType, 0.0297, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "15Y", fixedLegType, 0.0297, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "20Y", swapType,  0.0316, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "20Y", fixedLegType,  0.0316, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "25Y", swapType, 0.0335, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "25Y", fixedLegType, 0.0335, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "30Y", swapType, 0.0354, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "30Y", fixedLegType, 0.0354, fixedFreqType, accType)
     swaps.append(swap)
 
-    liborCurve = FinIborSingleCurve(settlementDate, depos, [], swaps,
+    liborCurve = FinIborSingleCurve(valuationDate, depos, [], swaps,
                                     FinInterpTypes.LINEAR_ZERO_RATES)
 
     exerciseDate = settlementDate.addTenor("5Y")
@@ -203,7 +205,7 @@ def test_FinIborSwaptionQLExample():
     swapFloatFrequencyType = FinFrequencyTypes.QUARTERLY
     swapFloatDayCountType = FinDayCountTypes.ACT_360
     swapNotional = 1000000
-    swaptionType = FinSwapTypes.PAYER
+    swaptionType = FinSwapTypes.PAY
 
     swaption = FinIborSwaption(settlementDate,
                                exerciseDate,
@@ -266,31 +268,31 @@ def testFinIborCashSettledSwaption():
     swaps = []
     accType = FinDayCountTypes.ACT_365F
     fixedFreqType = FinFrequencyTypes.SEMI_ANNUAL
-    swapType = FinSwapTypes.PAYER
+    fixedLegType = FinSwapTypes.PAY
     
-    swap = FinIborSwap(settlementDate, "3Y", swapType, 0.00790, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "3Y", fixedLegType, 0.00790, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "4Y", swapType, 0.01200, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "4Y", fixedLegType, 0.01200, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "5Y", swapType, 0.01570, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "5Y", fixedLegType, 0.01570, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "6Y", swapType, 0.01865, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "6Y", fixedLegType, 0.01865, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "7Y", swapType, 0.02160, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "7Y", fixedLegType, 0.02160, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "8Y", swapType, 0.02350, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "8Y", fixedLegType, 0.02350, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "9Y", swapType, 0.02540, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "9Y", fixedLegType, 0.02540, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "10Y", swapType, 0.0273, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "10Y", fixedLegType, 0.0273, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "15Y", swapType, 0.0297, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "15Y", fixedLegType, 0.0297, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "20Y", swapType, 0.0316, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "20Y", fixedLegType, 0.0316, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "25Y", swapType, 0.0335, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "25Y", fixedLegType, 0.0335, fixedFreqType, accType)
     swaps.append(swap)
-    swap = FinIborSwap(settlementDate, "30Y", swapType, 0.0354, fixedFreqType, accType)
+    swap = FinIborSwap(settlementDate, "30Y", fixedLegType, 0.0354, fixedFreqType, accType)
     swaps.append(swap)
 
     liborCurve = FinIborSingleCurve(valuationDate, depos, [], swaps,
@@ -304,12 +306,12 @@ def testFinIborCashSettledSwaption():
     swapFloatFrequencyType = FinFrequencyTypes.QUARTERLY
     swapFloatDayCountType = FinDayCountTypes.ACT_360
     swapNotional = 1000000
-    swapType = FinSwapTypes.PAYER
+    fixedLegType = FinSwapTypes.PAY
 
     swaption = FinIborSwaption(settlementDate,
                                 exerciseDate,
                                 swapMaturityDate,
-                                swapType,
+                                fixedLegType,
                                 swapFixedCoupon,
                                 swapFixedFrequencyType,
                                 swapFixedDayCountType,
@@ -330,7 +332,7 @@ def testFinIborCashSettledSwaption():
 
     fwdSwap = FinIborSwap(exerciseDate, 
                           swapMaturityDate, 
-                          swapType, 
+                          fixedLegType, 
                           swapFixedCoupon, 
                           swapFixedFrequencyType, 
                           swapFixedDayCountType)
@@ -373,8 +375,8 @@ def testFinIborSwaptionMatlabExamples():
     fixedDayCountType = FinDayCountTypes.THIRTY_E_360_ISDA
     notional = 100.0
 
-    # Pricing a PAYER
-    swaptionType = FinSwapTypes.PAYER
+    # Pricing a PAY
+    swaptionType = FinSwapTypes.PAY
     swaption = FinIborSwaption(settlementDate,
                                 exerciseDate,
                                 maturityDate,
@@ -426,7 +428,7 @@ def testFinIborSwaptionMatlabExamples():
     notional = 1000.0
 
     # Pricing a put
-    swaptionType = FinSwapTypes.RECEIVER
+    swaptionType = FinSwapTypes.RECEIVE
     swaption = FinIborSwaption(settlementDate,
                                 exerciseDate,
                                 maturityDate,
@@ -478,8 +480,8 @@ def testFinIborSwaptionMatlabExamples():
     floatDayCountType = FinDayCountTypes.THIRTY_E_360_ISDA
     notional = 1000.0
 
-    # Pricing a PAYER
-    swaptionType = FinSwapTypes.PAYER
+    # Pricing a PAY
+    swaptionType = FinSwapTypes.PAY
     swaption = FinIborSwaption(settlementDate,
                                 exerciseDate,
                                 maturityDate,
@@ -516,7 +518,7 @@ def testFinIborSwaptionMatlabExamples():
              FinDate(1, 1, 2011), FinDate(1, 7, 2011), FinDate(1, 1, 2012)]
 
     zeroRates = np.array([0.075] * 11)
-    interpType = FinInterpTypes.FLAT_FORWARDS
+    interpType = FinInterpTypes.FLAT_FWD_RATES
     dayCountType = FinDayCountTypes.THIRTY_E_360_ISDA
     contFreq = FinFrequencyTypes.SEMI_ANNUAL
 
@@ -533,7 +535,7 @@ def testFinIborSwaptionMatlabExamples():
     fixedDayCountType = FinDayCountTypes.THIRTY_E_360_ISDA
     notional = 100.0
 
-    swaptionType = FinSwapTypes.RECEIVER
+    swaptionType = FinSwapTypes.RECEIVE
     swaption = FinIborSwaption(settlementDate,
                                 exerciseDate,
                                 maturityDate,
@@ -568,7 +570,7 @@ def testFinIborSwaptionMatlabExamples():
 
     zeroRates = np.array([0.07] * 11)
 
-    interpType = FinInterpTypes.FLAT_FORWARDS
+    interpType = FinInterpTypes.FLAT_FWD_RATES
     dayCountType = FinDayCountTypes.THIRTY_E_360_ISDA
     contFreq = FinFrequencyTypes.SEMI_ANNUAL
 
@@ -586,7 +588,7 @@ def testFinIborSwaptionMatlabExamples():
     model = FinModelRatesBK(0.1, 0.05, 200)
 
     fixedCoupon = 0.07
-    swaptionType = FinSwapTypes.PAYER
+    swaptionType = FinSwapTypes.PAY
     swaption = FinIborSwaption(settlementDate,
                                 exerciseDate,
                                 maturityDate,
@@ -605,7 +607,7 @@ def testFinIborSwaptionMatlabExamples():
     testCases.print("DIFF:", v_finpy - v_matlab)
 
     fixedCoupon = 0.0725
-    swaptionType = FinSwapTypes.RECEIVER
+    swaptionType = FinSwapTypes.RECEIVE
     swaption = FinIborSwaption(settlementDate,
                                 exerciseDate,
                                 maturityDate,
@@ -640,7 +642,7 @@ def testFinIborSwaptionMatlabExamples():
 
     zeroRates = np.array([0.06] * 11)
 
-    interpType = FinInterpTypes.FLAT_FORWARDS
+    interpType = FinInterpTypes.FLAT_FWD_RATES
     dayCountType = FinDayCountTypes.THIRTY_E_360_ISDA
     contFreq = FinFrequencyTypes.ANNUAL
 
@@ -656,7 +658,7 @@ def testFinIborSwaptionMatlabExamples():
     notional = 100.0
 
     fixedCoupon = 0.062
-    swaptionType = FinSwapTypes.PAYER
+    swaptionType = FinSwapTypes.PAY
     swaption = FinIborSwaption(settlementDate,
                                 exerciseDate,
                                 maturityDate,
