@@ -1,6 +1,13 @@
-# -*- coding: utf-8 -*-
+##############################################################################
+# Copyright (C) 2018, 2019, 2020 Dominic O'Kane
+##############################################################################
 
 import time as time
+import numpy as np
+
+import sys
+sys.path.append("..")
+
 from financepy.market.volatility.FinIborCapVolCurve import FinIborCapVolCurve
 from financepy.finutils.FinDate import FinDate
 from financepy.finutils.FinDayCount import FinDayCountTypes
@@ -10,7 +17,6 @@ from financepy.finutils.FinFrequency import FinFrequencyTypes
 from financepy.products.funding.FinIborSwaption import FinSwapTypes
 from financepy.products.funding.FinIborSwaption import FinIborSwaption
 from financepy.finutils.FinHelperFunctions import checkVectorDifferences
-
 from financepy.models.FinModelRatesLMM import LMMSimulateFwdsNF
 from financepy.models.FinModelRatesLMM import LMMSimulateFwds1F
 from financepy.models.FinModelRatesLMM import LMMSimulateFwdsMF
@@ -23,16 +29,10 @@ from financepy.models.FinModelRatesLMM import LMMSwapPricer
 from financepy.models.FinModelRatesLMM import LMMFwdFwdCorrelation
 from financepy.models.FinModelRatesLMM import LMMRatchetCapletPricer
 from financepy.models.FinModelRatesLMM import LMMStickyCapletPricer
-# from financepy.models.FinModelRatesLMM import LMMFlexiCapPricer
-# from financepy.models.FinModelRatesLMM import LMMPrintForwards
-
-import numpy as np
 
 from FinTestCases import FinTestCases, globalTestCaseMode
-
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
-
 ###############################################################################
 
 
@@ -124,7 +124,7 @@ def getForwardCurve(numFwds, r):
 #     fwdsNF = LMMSimulateFwdsNF(numFwds, numPaths, fwd0,
 #                                zetas, correl, taus, seed)
 #     strike = r
-#     payerSwaption = 1
+#     PAYSwaption = 1
 #     useSobol = 0
 #     numeraireIndex = 0
 
@@ -138,10 +138,10 @@ def getForwardCurve(numFwds, r):
 #         print(a, b)
 
 #         swaptionPrice1F = LMMSwaptionPricer(strike, a, b, numPaths,
-#                                             fwd0, fwds1F, taus, payerSwaption)
+#                                             fwd0, fwds1F, taus, PAYSwaption)
 
 #         swaptionPriceNF = LMMSwaptionPricer(strike, a, b, numPaths,
-#                                             fwd0, fwdsNF, taus, payerSwaption)
+#                                             fwd0, fwdsNF, taus, PAYSwaption)
 
 #         swaptionVol = LMMSwaptionVolApprox(a, b, fwd0, taus, zetas, correl)
 
@@ -163,8 +163,8 @@ def getForwardCurve(numFwds, r):
 #         floatDayCountType = FinDayCountTypes.ACT_ACT_ISDA
 #         notional = 1.0
 
-#         # Pricing a PAYER
-#         swaptionType = FinIborSwaptionTypes.PAYER
+#         # Pricing a PAY
+#         swaptionType = FinIborSwaptionTypes.PAY
 #         swaption = FinIborSwaption(settlementDate,
 #                                     exerciseDate,
 #                                     maturityDate,
