@@ -2,15 +2,16 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
-
+import sys
+sys.path.append("..")
 
 from financepy.models.FinModelSABR import blackVolFromSABR
-import sys
-sys.path.append("..//..")
 
+from FinTestCases import FinTestCases, globalTestCaseMode
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
+###############################################################################
+
 alpha = 0.28
 beta = 1.0
 rho = -0.09
